summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorEgbert Eich <eich@freedesktop.org>2004-02-27 21:30:43 +0000
committerEgbert Eich <eich@freedesktop.org>2004-02-27 21:30:43 +0000
commit48e9a236cab6cb987f67ad596c4412c215d7a98b (patch)
tree4aba149d6705eec6d0a34ae1f05d7d9a24ed884d
parent1f42e6ce18e72eabf5fe02a3a693fca58267dfd3 (diff)
downloadxorg-lib-libX11-48e9a236cab6cb987f67ad596c4412c215d7a98b.tar.gz
5. Reversed Xinerama changes (Egbert Eich). 4. Reversed Xutf8* to XFree86utf8* function name changes for the release (Egbert Eich). 3. Removed sources for patch which were included when patch had a bad bug (Egbert Eich). 2. Removed unnecessary fonts (Egbert Eich). 1. Removed XIE and PEX extension files from release tree. The build environment has been gone already (Egbert Eich).
-rw-r--r--include/X11/Xlib.h42
-rw-r--r--include/X11/Xutil.h17
-rw-r--r--man/XSetWMProperties.man22
-rw-r--r--man/XStringListToTextProperty.man4
-rw-r--r--man/XmbDrawImageString.man10
-rw-r--r--man/XmbDrawString.man8
-rw-r--r--man/XmbDrawText.man16
-rw-r--r--man/XmbLookupString.man20
-rw-r--r--man/XmbResetIC.man12
-rw-r--r--man/XmbTextEscapement.man8
-rw-r--r--man/XmbTextExtents.man10
-rw-r--r--man/XmbTextListToTextProperty.man32
-rw-r--r--man/XmbTextPerCharExtents.man12
-rw-r--r--modules/im/ximcp/imDefIc.c10
-rw-r--r--modules/im/ximcp/imDefIm.c8
-rw-r--r--modules/im/ximcp/imDefLkup.c4
-rw-r--r--modules/im/ximcp/imLcIc.c2
-rw-r--r--modules/im/ximcp/imLcIm.c6
-rw-r--r--modules/im/ximcp/imLcLkup.c4
-rw-r--r--modules/im/ximcp/imLcPrs.c4
-rw-r--r--modules/im/ximcp/imThaiFlt.c2
-rw-r--r--modules/im/ximcp/imThaiIc.c2
-rw-r--r--modules/im/ximcp/imThaiIm.c6
-rw-r--r--modules/lc/Utf8/lcUTF8Load.c4
-rw-r--r--modules/lc/def/lcDefConv.c2
-rw-r--r--modules/lc/gen/lcGenConv.c2
-rw-r--r--modules/lc/xlocale/lcEuc.c2
-rw-r--r--modules/lc/xlocale/lcJis.c2
-rw-r--r--modules/lc/xlocale/lcSjis.c2
-rw-r--r--modules/om/generic/omDefault.c28
-rw-r--r--modules/om/generic/omGeneric.c40
-rw-r--r--modules/om/generic/omImText.c6
-rw-r--r--modules/om/generic/omText.c6
-rw-r--r--modules/om/generic/omTextEsc.c4
-rw-r--r--modules/om/generic/omTextExt.c6
-rw-r--r--modules/om/generic/omTextPer.c19
-rw-r--r--modules/om/generic/omXChar.c4
-rw-r--r--src/XomGeneric.h30
-rw-r--r--src/imConv.c6
-rw-r--r--src/xlibi18n/ICWrap.c41
-rw-r--r--src/xlibi18n/Ximint.h6
-rw-r--r--src/xlibi18n/XlcPubI.h10
-rw-r--r--src/xlibi18n/XlcPublic.h2
-rw-r--r--src/xlibi18n/Xlcint.h4
-rw-r--r--src/xlibi18n/lcPrTxt.c10
-rw-r--r--src/xlibi18n/lcPublic.c4
-rw-r--r--src/xlibi18n/lcStd.c8
-rw-r--r--src/xlibi18n/lcTxtPr.c10
-rw-r--r--src/xlibi18n/lcUTF8.c35
-rw-r--r--src/xlibi18n/lcWrap.c29
-rw-r--r--src/xlibi18n/utf8WMProps.c24
-rw-r--r--src/xlibi18n/utf8Wrap.c104
52 files changed, 260 insertions, 451 deletions
diff --git a/include/X11/Xlib.h b/include/X11/Xlib.h
index e16413e9..3f69be96 100644
--- a/include/X11/Xlib.h
+++ b/include/X11/Xlib.h
@@ -1,4 +1,4 @@
-/* $XdotOrg: lib/X11/include/X11/Xlib.h,v 1.1.4.7 2004-02-24 20:26:32 kaleb Exp $ */
+/* $XdotOrg: lib/X11/include/X11/Xlib.h,v 1.1.4.7.2.1 2004-02-27 21:30:50 eich Exp $ */
/* $Xorg: Xlib.h,v 1.6 2001/02/09 02:03:38 xorgcvs Exp $ */
/*
@@ -3654,14 +3654,11 @@ extern int XwcTextEscapement(
int /* num_wchars */
);
-extern int XFree86utf8TextEscapement(
+extern int Xutf8TextEscapement(
XFontSet /* font_set */,
_Xconst char* /* text */,
int /* bytes_text */
);
-#ifndef NOXFREE86COMPAT
-#define Xutf8TextEscapement XFree86utf8TextEscapement
-#endif
extern int XmbTextExtents(
XFontSet /* font_set */,
@@ -3679,16 +3676,13 @@ extern int XwcTextExtents(
XRectangle* /* overall_logical_return */
);
-extern int XFree86utf8TextExtents(
+extern int Xutf8TextExtents(
XFontSet /* font_set */,
_Xconst char* /* text */,
int /* bytes_text */,
XRectangle* /* overall_ink_return */,
XRectangle* /* overall_logical_return */
);
-#ifndef NOXFREE86COMPAT
-#define Xutf8TextExtents XFree86utf8TextExtents
-#endif
extern Status XmbTextPerCharExtents(
XFontSet /* font_set */,
@@ -3714,7 +3708,7 @@ extern Status XwcTextPerCharExtents(
XRectangle* /* overall_logical_return */
);
-extern Status XFree86utf8TextPerCharExtents(
+extern Status Xutf8TextPerCharExtents(
XFontSet /* font_set */,
_Xconst char* /* text */,
int /* bytes_text */,
@@ -3725,9 +3719,6 @@ extern Status XFree86utf8TextPerCharExtents(
XRectangle* /* overall_ink_return */,
XRectangle* /* overall_logical_return */
);
-#ifndef NOXFREE86COMPAT
-#define Xutf8TextPerCharExtents XFree86utf8TextPerCharExtents
-#endif
extern void XmbDrawText(
Display* /* display */,
@@ -3749,7 +3740,7 @@ extern void XwcDrawText(
int /* nitems */
);
-extern void XFree86utf8DrawText(
+extern void Xutf8DrawText(
Display* /* display */,
Drawable /* d */,
GC /* gc */,
@@ -3758,9 +3749,6 @@ extern void XFree86utf8DrawText(
XmbTextItem* /* text_items */,
int /* nitems */
);
-#ifndef NOXFREE86COMPAT
-#define Xutf8DrawText XFree86utf8DrawText
-#endif
extern void XmbDrawString(
Display* /* display */,
@@ -3784,7 +3772,7 @@ extern void XwcDrawString(
int /* num_wchars */
);
-extern void XFree86utf8DrawString(
+extern void Xutf8DrawString(
Display* /* display */,
Drawable /* d */,
XFontSet /* font_set */,
@@ -3794,9 +3782,6 @@ extern void XFree86utf8DrawString(
_Xconst char* /* text */,
int /* bytes_text */
);
-#ifndef NOXFREE86COMPAT
-#define Xutf8DrawString XFree86utf8DrawString
-#endif
extern void XmbDrawImageString(
Display* /* display */,
@@ -3820,7 +3805,7 @@ extern void XwcDrawImageString(
int /* num_wchars */
);
-extern void XFree86utf8DrawImageString(
+extern void Xutf8DrawImageString(
Display* /* display */,
Drawable /* d */,
XFontSet /* font_set */,
@@ -3830,9 +3815,6 @@ extern void XFree86utf8DrawImageString(
_Xconst char* /* text */,
int /* bytes_text */
);
-#ifndef NOXFREE86COMPAT
-#define Xutf8DrawImageString XFree86utf8DrawImageString
-#endif
extern XIM XOpenIM(
Display* /* dpy */,
@@ -3885,12 +3867,9 @@ extern char *XmbResetIC(
XIC /* ic */
);
-extern char *XFree86utf8ResetIC(
+extern char *Xutf8ResetIC(
XIC /* ic */
);
-#ifndef NOXFREE86COMPAT
-#define Xutf8ResetIC XFree86utf8ResetIC
-#endif
extern char *XSetICValues(
XIC /* ic */, ...
@@ -3927,7 +3906,7 @@ extern int XwcLookupString(
Status* /* status_return */
);
-extern int XFree86utf8LookupString(
+extern int Xutf8LookupString(
XIC /* ic */,
XKeyPressedEvent* /* event */,
char* /* buffer_return */,
@@ -3935,9 +3914,6 @@ extern int XFree86utf8LookupString(
KeySym* /* keysym_return */,
Status* /* status_return */
);
-#ifndef NOXFREE86COMPAT
-#define Xutf8LookupString XFree86utf8LookupString
-#endif
extern XVaNestedList XVaCreateNestedList(
int /*unused*/, ...
diff --git a/include/X11/Xutil.h b/include/X11/Xutil.h
index 0450f78e..85b299d3 100644
--- a/include/X11/Xutil.h
+++ b/include/X11/Xutil.h
@@ -170,7 +170,7 @@ typedef enum {
XTextStyle, /* text in owner's encoding (current locale)*/
XStdICCTextStyle, /* STRING, else COMPOUND_TEXT */
/* The following is an XFree86 extension, introduced in November 2000 */
- XFree86Utf8StringStyle /* UTF8_STRING */
+ XUTF8StringStyle /* UTF8_STRING */
} XICCEncodingStyle;
typedef struct {
@@ -672,7 +672,7 @@ extern void XmbSetWMProperties(
XClassHint* /* class_hints */
);
-extern void XFree86utf8SetWMProperties(
+extern void Xutf8SetWMProperties(
Display* /* display */,
Window /* w */,
_Xconst char* /* window_name */,
@@ -683,9 +683,6 @@ extern void XFree86utf8SetWMProperties(
XWMHints* /* wm_hints */,
XClassHint* /* class_hints */
);
-#ifndef NOXFREE86COMPAT
-#define Xutf8SetWMProperties XFree86utf8SetWMProperties
-#endif
extern void XSetWMSizeHints(
Display* /* display */,
@@ -747,16 +744,13 @@ extern int XwcTextListToTextProperty(
XTextProperty* text_prop_return
);
-extern int XFree86utf8TextListToTextProperty(
+extern int Xutf8TextListToTextProperty(
Display* display,
char** list,
int count,
XICCEncodingStyle style,
XTextProperty* text_prop_return
);
-#ifndef NOXFREE86COMPAT
-#define Xutf8TextListToTextProperty XFree86utf8TextListToTextProperty
-#endif
extern void XwcFreeStringList(
wchar_t** list
@@ -782,15 +776,12 @@ extern int XwcTextPropertyToTextList(
int* count_return
);
-extern int XFree86utf8TextPropertyToTextList(
+extern int Xutf8TextPropertyToTextList(
Display* display,
const XTextProperty* text_prop,
char*** list_return,
int* count_return
);
-#ifndef NOXFREE86COMPAT
-#define Xutf8TextPropertyToTextList XFree86utf8TextPropertyToTextList
-#endif
extern int XUnionRectWithRegion(
XRectangle* /* rectangle */,
diff --git a/man/XSetWMProperties.man b/man/XSetWMProperties.man
index ece91390..743586e5 100644
--- a/man/XSetWMProperties.man
+++ b/man/XSetWMProperties.man
@@ -143,7 +143,7 @@
.ny0
.TH XSetWMProperties 3X11 __xorgversion__ "XLIB FUNCTIONS"
.SH NAME
-XSetWMProperties, XmbSetWMProperties, XFree86utf8SetWMProperties \- set standard window properties
+XSetWMProperties, XmbSetWMProperties, Xutf8SetWMProperties \- set standard window properties
.SH SYNTAX
.HP
void XSetWMProperties\^(\^Display *\fIdisplay\fP\^, Window \fIw\fP\^,
@@ -156,7 +156,7 @@ void XmbSetWMProperties\^(\^Display *\fIdisplay\fP\^, Window \fIw\fP\^, char
\fIargc\fP\^, XSizeHints *\fInormal_hints\fP\^, XWMHints *\fIwm_hints\fP\^,
XClassHint *\fIclass_hints\fP\^);
.HP
-void XFree86utf8SetWMProperties\^(\^Display *\fIdisplay\fP\^, Window \fIw\fP\^, char
+void Xutf8SetWMProperties\^(\^Display *\fIdisplay\fP\^, Window \fIw\fP\^, char
*\fIwindow_name\fP\^, char *\fIicon_name\fP\^, char *\fIargv\fP\^[], int
\fIargc\fP\^, XSizeHints *\fInormal_hints\fP\^, XWMHints *\fIwm_hints\fP\^,
XClassHint *\fIclass_hints\fP\^);
@@ -243,7 +243,7 @@ any directory prefixes, is substituted for res_name.
The
.ZN XmbSetWMProperties
and
-.ZN XFree86utf8SetWMProperties
+.ZN Xutf8SetWMProperties
convenience functions provide a simple programming interface
for setting those essential window properties that are used
for communicating with other clients
@@ -256,7 +256,7 @@ they set the WM_ICON_NAME property.
The window_name and icon_name arguments are null-terminated strings, for
.ZN XmbSetWMProperties
in the encoding of the current locale, for
-.ZN XFree86utf8SetWMProperties
+.ZN Xutf8SetWMProperties
in UTF-8 encoding.
If the arguments can be fully converted to the STRING encoding,
the properties are created with type ``STRING'';
@@ -266,14 +266,14 @@ and the properties are created with type ``COMPOUND_TEXT''.
If the normal_hints argument is non-NULL,
.ZN XmbSetWMProperties
and
-.ZN XFree86utf8SetWMProperties
+.ZN Xutf8SetWMProperties
call
.ZN XSetWMNormalHints ,
which sets the WM_NORMAL_HINTS property (see section 14.1.7).
If the wm_hints argument is non-NULL,
.ZN XmbSetWMProperties
and
-.ZN XFree86utf8SetWMProperties
+.ZN Xutf8SetWMProperties
call
.ZN XSetWMHints ,
which sets the WM_HINTS property (see section 14.1.6).
@@ -281,7 +281,7 @@ which sets the WM_HINTS property (see section 14.1.6).
If the argv argument is non-NULL,
.ZN XmbSetWMProperties
and
-.ZN XFree86utf8SetWMProperties
+.ZN Xutf8SetWMProperties
set the WM_COMMAND property from argv and argc.
An argc of zero indicates a zero-length command.
.LP
@@ -292,7 +292,7 @@ The hostname of the machine is stored using
If the class_hints argument is non-NULL,
.ZN XmbSetWMProperties
and
-.ZN XFree86utf8SetWMProperties
+.ZN Xutf8SetWMProperties
set the WM_CLASS property.
If the res_name member in the
.ZN XClassHint
@@ -315,7 +315,7 @@ in the properties.
For clients that need to process the property text in a locale,
.ZN XmbSetWMProperties
and
-.ZN XFree86utf8SetWMProperties
+.ZN Xutf8SetWMProperties
set the WM_LOCALE_NAME property to be the name of the current locale.
The name is assumed to be in the Host Portable Character Encoding
and is converted to STRING for storage in the property.
@@ -323,7 +323,7 @@ and is converted to STRING for storage in the property.
.ZN XSetWMProperties ,
.ZN XmbSetWMProperties
and
-.ZN XFree86utf8SetWMProperties
+.ZN Xutf8SetWMProperties
can generate
.ZN BadAlloc
and
@@ -331,7 +331,7 @@ and
errors.
.LP
The function
-.ZN XFree86utf8SetWMProperties
+.ZN Xutf8SetWMProperties
is an XFree86 extension introduced in XFree86 4.0.2. Its presence is
indicated by the macro
.ZN X_HAVE_UTF8_STRING .
diff --git a/man/XStringListToTextProperty.man b/man/XStringListToTextProperty.man
index 425c8069..b76bf033 100644
--- a/man/XStringListToTextProperty.man
+++ b/man/XStringListToTextProperty.man
@@ -42,7 +42,7 @@
.\" It is provided ``as is'' without express or implied warranty.
.\"
.\" $XFree86: xc/doc/man/X11/XSLTTProp.man,v 1.6 2003/11/23 05:40:33 dawes Exp $
-.\" $XdotOrg: lib/X11/man/XStringListToTextProperty.man,v 1.1.4.4 2003-12-08 21:35:37 kaleb Exp $
+.\" $XdotOrg: lib/X11/man/XStringListToTextProperty.man,v 1.1.4.4.4.1 2004-02-27 21:30:43 eich Exp $
.\"
.ds xT X Toolkit Intrinsics \- C Language Interface
.ds xW Athena X Widgets \- C Language X Toolkit Interface
@@ -216,7 +216,7 @@ The
.ZN XFreeStringList
function releases memory allocated by
.ZN XmbTextPropertyToTextList ,
-.ZN XFree86utf8TextPropertyToTextList
+.ZN Xutf8TextPropertyToTextList
and
.ZN XTextPropertyToStringList
and the missing charset list allocated by
diff --git a/man/XmbDrawImageString.man b/man/XmbDrawImageString.man
index 61abeac7..80725e97 100644
--- a/man/XmbDrawImageString.man
+++ b/man/XmbDrawImageString.man
@@ -143,7 +143,7 @@
.ny0
.TH XmbDrawImageString 3X11 __xorgversion__ "XLIB FUNCTIONS"
.SH NAME
-XmbDrawImageString, XwcDrawImageString, XFree86utf8DrawImageString \- draw image text using a single font set
+XmbDrawImageString, XwcDrawImageString, Xutf8DrawImageString \- draw image text using a single font set
.SH SYNTAX
.HP
void XmbDrawImageString\^(\^Display *\fIdisplay\fP\^, Drawable \fId\fP\^,
@@ -154,7 +154,7 @@ void XwcDrawImageString\^(\^Display *\fIdisplay\fP\^, Drawable \fId\fP\^,
XFontSet \fIfont_set\fP\^, GC \fIgc\fP\^, int \fIx\fP\^, int \fIy\fP\^,
wchar_t *\fIstring\fP\^, int \fInum_wchars\fP\^);
.HP
-void XFree86utf8DrawImageString\^(\^Display *\fIdisplay\fP\^, Drawable \fId\fP\^,
+void Xutf8DrawImageString\^(\^Display *\fIdisplay\fP\^, Drawable \fId\fP\^,
XFontSet \fIfont_set\fP\^, GC \fIgc\fP\^, int \fIx\fP\^, int \fIy\fP\^, char
*\fIstring\fP\^, int \fInum_bytes\fP\^);
.SH ARGUMENTS
@@ -183,14 +183,14 @@ The
.ZN XmbDrawImageString ,
.ZN XwcDrawImageString
and
-.ZN XFree86utf8DrawImageString
+.ZN Xutf8DrawImageString
functions fill a destination rectangle with the background pixel defined
in the GC and then paint the text with the foreground pixel.
The filled rectangle is the rectangle returned to overall_logical_return by
.ZN XmbTextExtents ,
.ZN XwcTextExtents
or
-.ZN XFree86utf8TextExtents
+.ZN Xutf8TextExtents
for the same text and
.ZN XFontSet .
.LP
@@ -202,7 +202,7 @@ with the default string returned by
The behavior for an invalid codepoint is undefined.
.LP
The function
-.ZN XFree86utf8TextExtents
+.ZN Xutf8TextExtents
is an XFree86 extension introduced in XFree86 4.0.2. Its presence is
indicated by the macro
.ZN X_HAVE_UTF8_STRING .
diff --git a/man/XmbDrawString.man b/man/XmbDrawString.man
index 21410cbb..f3e52634 100644
--- a/man/XmbDrawString.man
+++ b/man/XmbDrawString.man
@@ -143,7 +143,7 @@
.ny0
.TH XmbDrawString 3X11 __xorgversion__ "XLIB FUNCTIONS"
.SH NAME
-XmbDrawString, XwcDrawString, XFree86utf8DrawString \- draw text using a single font set
+XmbDrawString, XwcDrawString, Xutf8DrawString \- draw text using a single font set
.SH SYNTAX
.HP
void XmbDrawString\^(\^Display *\fIdisplay\fP\^, Drawable \fId\fP\^, XFontSet
@@ -154,7 +154,7 @@ void XwcDrawString\^(\^Display *\fIdisplay\fP\^, Drawable \fId\fP\^, XFontSet
\fIfont_set\fP\^, GC \fIgc\fP\^, int \fIx\fP\^, int \fIy\fP\^, wchar_t
*\fIstring\fP\^, int \fInum_wchars\fP\^);
.HP
-void XFree86utf8DrawString\^(\^Display *\fIdisplay\fP\^, Drawable \fId\fP\^,
+void Xutf8DrawString\^(\^Display *\fIdisplay\fP\^, Drawable \fId\fP\^,
XFontSet \fIfont_set\fP\^, GC \fIgc\fP\^, int \fIx\fP\^, int \fIy\fP\^, char
*\fIstring\fP\^, int \fInum_bytes\fP\^);
.SH ARGUMENTS
@@ -183,7 +183,7 @@ The
.ZN XmbDrawString ,
.ZN XwcDrawString
and
-.ZN XFree86utf8DrawString
+.ZN Xutf8DrawString
functions draw the specified text with the foreground pixel.
When the
.ZN XFontSet
@@ -193,7 +193,7 @@ with the default string returned by
The behavior for an invalid codepoint is undefined.
.LP
The function
-.ZN XFree86utf8DrawString
+.ZN Xutf8DrawString
is an XFree86 extension introduced in XFree86 4.0.2. Its presence is
indicated by the macro
.ZN X_HAVE_UTF8_STRING .
diff --git a/man/XmbDrawText.man b/man/XmbDrawText.man
index 06ba844a..de6b35f0 100644
--- a/man/XmbDrawText.man
+++ b/man/XmbDrawText.man
@@ -42,7 +42,7 @@
.\" It is provided ``as is'' without express or implied warranty.
.\"
.\" $XFree86: xc/doc/man/X11/XmbDTxt.man,v 1.5 2003/11/23 05:40:33 dawes Exp $
-.\" $XdotOrg: lib/X11/man/XmbDrawText.man,v 1.1.4.4 2003-12-08 21:35:37 kaleb Exp $
+.\" $XdotOrg: lib/X11/man/XmbDrawText.man,v 1.1.4.4.4.1 2004-02-27 21:30:43 eich Exp $
.\"
.ds xT X Toolkit Intrinsics \- C Language Interface
.ds xW Athena X Widgets \- C Language X Toolkit Interface
@@ -144,7 +144,7 @@
.ny0
.TH XmbDrawText 3X11 __xorgversion__ "XLIB FUNCTIONS"
.SH NAME
-XmbDrawText, XwcDrawText, XFree86utf8DrawText \- draw text using multiple font sets
+XmbDrawText, XwcDrawText, Xutf8DrawText \- draw text using multiple font sets
.SH SYNTAX
.HP
void XmbDrawText\^(\^Display *\fIdisplay\fP\^, Drawable \fId\fP\^, GC
@@ -155,7 +155,7 @@ void XwcDrawText\^(\^Display *\fIdisplay\fP\^, Drawable \fId\fP\^, GC
\fIgc\fP\^, int \fIx\fP\^, int \fIy\fP\^, XwcTextItem *\fIitems\fP\^, int
\fInitems\fP\^);
.HP
-void XFree86utf8DrawText\^(\^Display *\fIdisplay\fP\^, Drawable \fId\fP\^, GC
+void Xutf8DrawText\^(\^Display *\fIdisplay\fP\^, Drawable \fId\fP\^, GC
\fIgc\fP\^, int \fIx\fP\^, int \fIy\fP\^, XmbTextItem *\fIitems\fP\^, int \fInitems\fP\^);
.SH ARGUMENTS
.IP \fId\fP 1i
@@ -179,7 +179,7 @@ The
.ZN XmbDrawText ,
.ZN XwcDrawText
and
-.ZN XFree86utf8DrawText
+.ZN Xutf8DrawText
functions allow complex spacing and font set shifts between text strings.
Each text item is processed in turn, with the origin of a text
element advanced in the primary draw direction by the escapement of the
@@ -197,16 +197,16 @@ will not be drawn.
.ZN XmbDrawText ,
.ZN XwcDrawText
and
-.ZN XFree86utf8DrawText
+.ZN Xutf8DrawText
do not perform any context-dependent rendering between text segments.
Clients may compute the drawing metrics by passing each text segment to
.ZN XmbTextExtents ,
.ZN XwcTextExtents ,
-.ZN XFree86utf8TextExtents
+.ZN Xutf8TextExtents
or
.ZN XmbTextPerCharExtents ,
.ZN XwcTextPerCharExtents .
-.ZN XFree86utf8TextPerCharExtents .
+.ZN Xutf8TextPerCharExtents .
When the
.ZN XFontSet
has missing charsets, each unavailable character is drawn
@@ -215,7 +215,7 @@ with the default string returned by
The behavior for an invalid codepoint is undefined.
.LP
The function
-.ZN XFree86utf8DrawText
+.ZN Xutf8DrawText
is an XFree86 extension introduced in XFree86 4.0.2. Its presence is
indicated by the macro
.ZN X_HAVE_UTF8_STRING .
diff --git a/man/XmbLookupString.man b/man/XmbLookupString.man
index 30e43478..32b09186 100644
--- a/man/XmbLookupString.man
+++ b/man/XmbLookupString.man
@@ -145,7 +145,7 @@
'\" t
.TH XmbLookupString 3X11 __xorgversion__ "XLIB FUNCTIONS"
.SH NAME
-XmbLookupString, XwcLookupString, XFree86utf8LookupString \- obtain composed input from an input method
+XmbLookupString, XwcLookupString, Xutf8LookupString \- obtain composed input from an input method
.SH SYNTAX
.HP
int XmbLookupString\^(\^XIC \fIic\fP\^, XKeyPressedEvent *\fIevent\fP, char
@@ -156,7 +156,7 @@ int XwcLookupString\^(\^XIC \fIic\fP\^, XKeyPressedEvent *\fIevent\fP\^,
wchar_t *\fIbuffer_return\fP\^, int \fIwchars_buffer\fP\^, KeySym
*\fIkeysym_return\fP\^, Status *\fIstatus_return\fP\^);
.HP
-int XFree86utf8LookupString\^(\^XIC \fIic\fP\^, XKeyPressedEvent *\fIevent\fP, char
+int Xutf8LookupString\^(\^XIC \fIic\fP\^, XKeyPressedEvent *\fIevent\fP, char
*\fIbuffer_return\fP\^, int \fIbytes_buffer\fP\^, KeySym
*\fIkeysym_return\fP\^, Status *\fIstatus_return\fP\^);
.SH ARGUMENTS
@@ -182,7 +182,7 @@ The
.ZN XmbLookupString ,
.ZN XwcLookupString
and
-.ZN XFree86utf8LookupString
+.ZN Xutf8LookupString
functions return the string from the input method specified
in the buffer_return argument.
If no string is returned,
@@ -196,7 +196,7 @@ the KeySym value does not necessarily correspond to the string returned.
.LP
.ZN XmbLookupString
and
-.ZN XFree86utf8LookupString
+.ZN Xutf8LookupString
return the length of the string in bytes, and
.ZN XwcLookupString
returns the length of the string in characters.
@@ -206,7 +206,7 @@ and
.ZN XwcLookupString
return text in the encoding of the locale bound to the input method
of the specified input context, and
-.ZN XFree86utf8LookupString
+.ZN Xutf8LookupString
returns text in UTF-8 encoding.
.LP
Each string returned by
@@ -223,7 +223,7 @@ events to
.ZN XmbLookupString ,
.ZN XwcLookupString
and
-.ZN XFree86utf8LookupString .
+.ZN Xutf8LookupString .
Their behavior when a client passes a
.ZN KeyRelease
event is undefined.
@@ -242,7 +242,7 @@ T} T{
The input string to be returned is too large for the supplied buffer_return.
The required size (for
.ZN XmbLookupString ,
-.ZN XFree86utf8LookupString
+.ZN Xutf8LookupString
in bytes; for
.ZN XwcLookupString
in characters) is returned as the value of the function,
@@ -289,18 +289,18 @@ It does not make any difference if the input context passed as an argument to
.ZN XmbLookupString ,
.ZN XwcLookupString
and
-.ZN XFree86utf8LookupString
+.ZN Xutf8LookupString
is the one currently in possession of the focus or not.
Input may have been composed within an input context before it lost the focus,
and that input may be returned on subsequent calls to
.ZN XmbLookupString ,
.ZN XwcLookupString
or
-.ZN XFree86utf8LookupString
+.ZN Xutf8LookupString
even though it does not have any more keyboard focus.
.LP
The function
-.ZN XFree86utf8LookupString
+.ZN Xutf8LookupString
is an XFree86 extension introduced in XFree86 4.0.2. Its presence is
indicated by the macro
.ZN X_HAVE_UTF8_STRING .
diff --git a/man/XmbResetIC.man b/man/XmbResetIC.man
index 0f857b57..cb249e16 100644
--- a/man/XmbResetIC.man
+++ b/man/XmbResetIC.man
@@ -143,14 +143,14 @@
.ny0
.TH XmbResetIC 3X11 __xorgversion__ "XLIB FUNCTIONS"
.SH NAME
-XmbResetIC, XwcResetIC, XFree86utf8ResetIC \- reset the state of an input context
+XmbResetIC, XwcResetIC, Xutf8ResetIC \- reset the state of an input context
.SH SYNTAX
.HP
char *XmbResetIC\^(\^XIC \fIic\fP\^);
.HP
wchar_t *XwcResetIC\^(\^XIC \fIic\fP\^);
.HP
-char *XFree86utf8ResetIC\^(\^XIC \fIic\fP\^);
+char *Xutf8ResetIC\^(\^XIC \fIic\fP\^);
.SH ARGUMENTS
.IP \fIic\fP 1i
Specifies the input context.
@@ -162,7 +162,7 @@ is set to
.ZN XmbResetIC ,
.ZN XwcResetIC
and
-.ZN XFree86utf8ResetIC
+.ZN Xutf8ResetIC
reset an input context to its initial state;
when
.ZN XNResetState
@@ -176,7 +176,7 @@ Calling
.ZN XmbResetIC ,
.ZN XwcResetIC
or
-.ZN XFree86utf8ResetIC
+.ZN Xutf8ResetIC
does not change the focus.
.LP
The return value of
@@ -186,7 +186,7 @@ The return value of
.ZN XwcResetIC
is its current preedit string as a wide character string.
The return value of
-.ZN XFree86utf8ResetIC
+.ZN Xutf8ResetIC
is its current preedit string as an UTF-8 string.
If there is any preedit text drawn or visible to the user,
then these procedures must return a non-NULL string.
@@ -198,7 +198,7 @@ The client should free the returned string by calling
.ZN XFree .
.LP
The function
-.ZN XFree86utf8ResetIC
+.ZN Xutf8ResetIC
is an XFree86 extension introduced in XFree86 4.0.2. Its presence is
indicated by the macro
.ZN X_HAVE_UTF8_STRING .
diff --git a/man/XmbTextEscapement.man b/man/XmbTextEscapement.man
index ce07f7ba..61d1256e 100644
--- a/man/XmbTextEscapement.man
+++ b/man/XmbTextEscapement.man
@@ -143,7 +143,7 @@
.ny0
.TH XmbTextEscapement 3X11 __xorgversion__ "XLIB FUNCTIONS"
.SH NAME
-XmbTextEscapement, XwcTextEscapement, XFree86utf8TextEscapement \- obtain the escapement of text
+XmbTextEscapement, XwcTextEscapement, Xutf8TextEscapement \- obtain the escapement of text
.SH SYNTAX
.HP
int XmbTextEscapement\^(\^XFontSet \fIfont_set\fP\^, char *\fIstring\fP\^, int
@@ -152,7 +152,7 @@ int XmbTextEscapement\^(\^XFontSet \fIfont_set\fP\^, char *\fIstring\fP\^, int
int XwcTextEscapement\^(\^XFontSet \fIfont_set\fP\^, wchar_t *\fIstring\fP\^,
int \fInum_wchars\fP\^);
.HP
-int XFree86utf8TextEscapement\^(\^XFontSet \fIfont_set\fP\^, char *\fIstring\fP\^,
+int Xutf8TextEscapement\^(\^XFontSet \fIfont_set\fP\^, char *\fIstring\fP\^,
int \fInum_bytes\fP\^);
.SH ARGUMENTS
.IP \fIfont_set\fP 1i
@@ -168,7 +168,7 @@ The
.ZN XmbTextEscapement ,
.ZN XwcTextEscapement
and
-.ZN XFree86utf8TextEscapement
+.ZN Xutf8TextEscapement
functions return the escapement in pixels of the specified string as a value,
using the fonts loaded for the specified font set.
The escapement is the distance in pixels in the primary draw
@@ -180,7 +180,7 @@ Regardless of the character rendering order,
the escapement is always positive.
.LP
The function
-.ZN XFree86utf8TextEscapement
+.ZN Xutf8TextEscapement
is an XFree86 extension introduced in XFree86 4.0.2. Its presence is
indicated by the macro
.ZN X_HAVE_UTF8_STRING .
diff --git a/man/XmbTextExtents.man b/man/XmbTextExtents.man
index aa5d89ee..d329148b 100644
--- a/man/XmbTextExtents.man
+++ b/man/XmbTextExtents.man
@@ -143,7 +143,7 @@
.ny0
.TH XmbTextExtents 3X11 __xorgversion__ "XLIB FUNCTIONS"
.SH NAME
-XmbTextExtents, XwcTextExtents, XFree86utf8TextExtents \- compute text extents
+XmbTextExtents, XwcTextExtents, Xutf8TextExtents \- compute text extents
.SH SYNTAX
.HP
int XmbTextExtents\^(\^XFontSet \fIfont_set\fP\^, char *\fIstring\fP\^, int
@@ -154,7 +154,7 @@ int XwcTextExtents\^(\^XFontSet \fIfont_set\fP\^, wchar_t *\fIstring\fP\^, int
\fInum_wchars\fP\^, XRectangle *\fIoverall_ink_return\fP\^, XRectangle
*\fIoverall_logical_return\fP\^);
.HP
-int XFree86utf8TextExtents\^(\^XFontSet \fIfont_set\fP\^, char *\fIstring\fP\^, int
+int Xutf8TextExtents\^(\^XFontSet \fIfont_set\fP\^, char *\fIstring\fP\^, int
\fInum_bytes\fP\^, XRectangle *\fIoverall_ink_return\fP\^, XRectangle
*\fIoverall_logical_return\fP\^);
.SH ARGUMENTS
@@ -176,7 +176,7 @@ The
.ZN XmbTextExtents ,
.ZN XwcTextExtents
and
-.ZN XFree86utf8TextExtents
+.ZN Xutf8TextExtents
functions set the components of the specified overall_ink_return and
overall_logical_return
arguments to the overall bounding box of the string's image
@@ -185,7 +185,7 @@ They return the value returned by
.ZN XmbTextEscapement ,
.ZN XwcTextEscapement
or
-.ZN XFree86utf8TextEscapement .
+.ZN Xutf8TextEscapement .
These metrics are relative to the drawing origin of the string,
using the fonts loaded for the specified font set.
.LP
@@ -216,7 +216,7 @@ so that the metrics represent the text as it will actually be drawn.
The behavior for an invalid codepoint is undefined.
.LP
The function
-.ZN XFree86utf8TextExtents
+.ZN Xutf8TextExtents
is an XFree86 extension introduced in XFree86 4.0.2. Its presence is
indicated by the macro
.ZN X_HAVE_UTF8_STRING .
diff --git a/man/XmbTextListToTextProperty.man b/man/XmbTextListToTextProperty.man
index 860fe494..68db1629 100644
--- a/man/XmbTextListToTextProperty.man
+++ b/man/XmbTextListToTextProperty.man
@@ -43,7 +43,7 @@
.\" It is provided ``as is'' without express or implied warranty.
.\"
.\" $XFree86: xc/doc/man/X11/XTLTTProp.man,v 1.7 2003/11/23 05:40:33 dawes Exp $
-.\" $XdotOrg: lib/X11/man/XmbTextListToTextProperty.man,v 1.1.4.4 2003-12-08 21:35:37 kaleb Exp $
+.\" $XdotOrg: lib/X11/man/XmbTextListToTextProperty.man,v 1.1.4.4.4.1 2004-02-27 21:30:43 eich Exp $
.\"
.ds xT X Toolkit Intrinsics \- C Language Interface
.ds xW Athena X Widgets \- C Language X Toolkit Interface
@@ -146,7 +146,7 @@
'\" t
.TH XmbTextListToTextProperty 3X11 __xorgversion__ "XLIB FUNCTIONS"
.SH NAME
-XmbTextListToTextProperty, XwcTextListToTextProperty, XFree86utf8TextListToTextProperty, XmbTextPropertyToTextList, XwcTextPropertyToTextList, XFree86utf8TextPropertyToTextList, XwcFreeStringList, XDefaultString \- convert text lists and text property structures
+XmbTextListToTextProperty, XwcTextListToTextProperty, Xutf8TextListToTextProperty, XmbTextPropertyToTextList, XwcTextPropertyToTextList, Xutf8TextPropertyToTextList, XwcFreeStringList, XDefaultString \- convert text lists and text property structures
.SH SYNTAX
.HP
int XmbTextListToTextProperty\^(\^Display *\fIdisplay\fP\^, char
@@ -157,7 +157,7 @@ int XwcTextListToTextProperty\^(\^Display *\fIdisplay\fP\^, wchar_t
**\fIlist\fP\^, int \fIcount\fP\^, XICCEncodingStyle \fIstyle\fP\^,
XTextProperty *\fItext_prop_return\fP\^);
.HP
-int XFree86utf8TextListToTextProperty\^(\^Display *\fIdisplay\fP\^, char
+int Xutf8TextListToTextProperty\^(\^Display *\fIdisplay\fP\^, char
**\fIlist\fP\^, int \fIcount\fP\^, XICCEncodingStyle \fIstyle\fP\^,
XTextProperty *\fItext_prop_return\fP\^);
.HP
@@ -168,7 +168,7 @@ int XwcTextPropertyToTextList\^(\^Display *\fIdisplay\fP\^, XTextProperty
*\fItext_prop\fP\^, wchar_t ***\fIlist_return\fP\^, int
*\fIcount_return\fP\^);
.HP
-int XFree86utf8TextPropertyToTextList\^(\^Display *\fIdisplay\fP\^, XTextProperty
+int Xutf8TextPropertyToTextList\^(\^Display *\fIdisplay\fP\^, XTextProperty
*\fItext_prop\fP\^, char ***\fIlist_return\fP\^, int *\fIcount_return\fP\^);
.HP
void XwcFreeStringList\^(\^wchar_t **\fIlist\fP\^);
@@ -203,7 +203,7 @@ The
.ZN XmbTextListToTextProperty ,
.ZN XwcTextListToTextProperty
and
-.ZN XFree86utf8TextListToTextProperty
+.ZN Xutf8TextListToTextProperty
functions set the specified
.ZN XTextProperty
value to a set of null-separated elements representing the concatenation
@@ -213,7 +213,7 @@ strings must be given in the current locale encoding (for
and
.ZN XwcTextListToTextProperty ),
or in UTF-8 encoding (for
-.ZN XFree86utf8TextListToTextProperty ).
+.ZN Xutf8TextListToTextProperty ).
.LP
The functions set the encoding field of text_prop_return to an
.ZN Atom
@@ -228,7 +228,7 @@ or
is specified,
this encoding is ``STRING'' or ``COMPOUND_TEXT'', respectively.
If the style
-.ZN XFree86Utf8StringStyle
+.ZN XUTF8StringStyle
is specified,
this encoding is ``UTF8_STRING''. (This is an XFree86 extension introduced in
XFree86 4.0.2. Its presence is indicated by the macro
@@ -276,7 +276,7 @@ The
.ZN XmbTextPropertyToTextList ,
.ZN XwcTextPropertyToTextList
and
-.ZN XFree86utf8TextPropertyToTextList
+.ZN Xutf8TextPropertyToTextList
functions return a list of text strings representing the
null-separated elements of the specified
.ZN XTextProperty
@@ -286,7 +286,7 @@ structure. The returned strings are encoded using the current locale encoding
and
.ZN XwcTextPropertyToTextList )
or in UTF-8 (for
-.ZN XFree86utf8TextPropertyToTextList ).
+.ZN Xutf8TextPropertyToTextList ).
The data in text_prop must be format 8.
.LP
Multiple elements of the property (for example, the strings in a disjoint
@@ -298,7 +298,7 @@ If insufficient memory is available for the list and its elements,
.ZN XmbTextPropertyToTextList ,
.ZN XwcTextPropertyToTextList
and
-.ZN XFree86utf8TextPropertyToTextList
+.ZN Xutf8TextPropertyToTextList
return
.ZN XNoMemory .
If the current locale is not supported,
@@ -324,7 +324,7 @@ Otherwise,
.ZN XmbTextPropertyToTextList ,
.ZN XwcTextPropertyToTextList
and
-.ZN XFree86utf8TextPropertyToTextList
+.ZN Xutf8TextPropertyToTextList
return the list of null-terminated text strings to list_return
and the number of text strings to count_return.
.LP
@@ -340,14 +340,14 @@ Otherwise,
.ZN XmbTextPropertyToTextList ,
.ZN XwcTextPropertyToTextList
and
-.ZN XFree86utf8TextPropertyToTextList
+.ZN Xutf8TextPropertyToTextList
return
.ZN Success .
.LP
To free the storage for the list and its contents returned by
.ZN XmbTextPropertyToTextList
or
-.ZN XFree86utf8TextPropertyToTextList ,
+.ZN Xutf8TextPropertyToTextList ,
use
.ZN XFreeStringList .
To free the storage for the list and its contents returned by
@@ -391,9 +391,9 @@ It may be freed after the current locale is changed.
Until freed, it will not be modified by Xlib.
.LP
The functions
-.ZN XFree86utf8TextListToTextProperty
+.ZN Xutf8TextListToTextProperty
and
-.ZN XFree86utf8TextPropertyToTextList
+.ZN Xutf8TextPropertyToTextList
are an XFree86 extension introduced in XFree86 4.0.2. Their presence is
indicated by the macro
.ZN X_HAVE_UTF8_STRING .
@@ -449,7 +449,7 @@ typedef enum {
XCompoundTextStyle, /\(** COMPOUND_TEXT */
XTextStyle, /\(** text in owner's encoding (current locale) */
XStdICCTextStyle, /\(** STRING, else COMPOUND_TEXT */
- XFree86Utf8StringStyle /\(** UTF8_STRING */
+ XUTF8StringStyle /\(** UTF8_STRING */
} XICCEncodingStyle;
.De
.SH "SEE ALSO"
diff --git a/man/XmbTextPerCharExtents.man b/man/XmbTextPerCharExtents.man
index a53852d9..084da3ea 100644
--- a/man/XmbTextPerCharExtents.man
+++ b/man/XmbTextPerCharExtents.man
@@ -143,7 +143,7 @@
.ny0
.TH XmbTextPerCharExtents 3X11 __xorgversion__ "XLIB FUNCTIONS"
.SH NAME
-XmbTextPerCharExtents, XwcTextPerCharExtents, XFree86utf8TextPerCharExtents \- obtain per-character information for a text string
+XmbTextPerCharExtents, XwcTextPerCharExtents, Xutf8TextPerCharExtents \- obtain per-character information for a text string
.SH SYNTAX
.HP
Status XmbTextPerCharExtents\^(\^XFontSet \fIfont_set\fP\^, char
@@ -158,7 +158,7 @@ Status XwcTextPerCharExtents\^(\^XFontSet \fIfont_set\fP\^, wchar_t
\fIarray_size\fP\^, int *\fInum_chars_return\fP\^, XRectangle
*\fIoverall_ink_return\fP\^, XRectangle *\fIoverall_logical_return\fP\^);
.HP
-Status XFree86utf8TextPerCharExtents\^(\^XFontSet \fIfont_set\fP\^, char
+Status Xutf8TextPerCharExtents\^(\^XFontSet \fIfont_set\fP\^, char
*\fIstring\fP\^, int \fInum_bytes\fP\^, XRectangle *\fIink_array_return\fP\^,
XRectangle *\fIlogical_array_return\fP\^, int \fIarray_size\fP\^, int
*\fInum_chars_return\fP\^, XRectangle *\fIoverall_ink_return\fP\^, XRectangle
@@ -191,7 +191,7 @@ The
.ZN XmbTextPerCharExtents ,
.ZN XwcTextPerCharExtents
and
-.ZN XFree86utf8TextPerCharExtents
+.ZN Xutf8TextPerCharExtents
functions return the text dimensions of each character of the specified text,
using the fonts loaded for the specified font set.
Each successive element of ink_array_return and logical_array_return
@@ -237,16 +237,16 @@ If the overall_ink_return or overall_logical_return argument is non-NULL,
.ZN XmbTextPerCharExtents ,
.ZN XwcTextPerCharExtents
and
-.ZN XFree86utf8TextPerCharExtents
+.ZN Xutf8TextPerCharExtents
return the maximum extent of the string's metrics to overall_ink_return
or overall_logical_return, as returned by
.ZN XmbTextExtents ,
.ZN XwcTextExtents
or
-.ZN XFree86utf8TextExtents .
+.ZN Xutf8TextExtents .
.LP
The function
-.ZN XFree86utf8TextPerCharExtents
+.ZN Xutf8TextPerCharExtents
is an XFree86 extension introduced in XFree86 4.0.2. Its presence is
indicated by the macro
.ZN X_HAVE_UTF8_STRING .
diff --git a/modules/im/ximcp/imDefIc.c b/modules/im/ximcp/imDefIc.c
index 98cd66dc..7d3a5cc4 100644
--- a/modules/im/ximcp/imDefIc.c
+++ b/modules/im/ximcp/imDefIc.c
@@ -1212,7 +1212,7 @@ _XimProtoWcReset(
}
Private char *
-_XFree86imCommitedUtf8String(
+_XimCommitedUtf8String(
Xim im,
Xic ic,
XPointer buf)
@@ -1262,10 +1262,10 @@ Error_On_Reset:
}
Private char *
-_XFree86imProtoUtf8Reset(
+_XimProtoUtf8Reset(
XIC xic)
{
- return _XimProtoReset(xic, _XFree86imCommitedUtf8String);
+ return _XimProtoReset(xic, _XimCommitedUtf8String);
}
Private XICMethodsRec ic_methods = {
@@ -1276,10 +1276,10 @@ Private XICMethodsRec ic_methods = {
_XimProtoGetICValues, /* get_values */
_XimProtoMbReset, /* mb_reset */
_XimProtoWcReset, /* wc_reset */
- _XFree86imProtoUtf8Reset, /* utf8_reset */
+ _XimProtoUtf8Reset, /* utf8_reset */
_XimProtoMbLookupString, /* mb_lookup_string */
_XimProtoWcLookupString, /* wc_lookup_string */
- _XFree86imProtoUtf8LookupString /* utf8_lookup_string */
+ _XimProtoUtf8LookupString /* utf8_lookup_string */
};
Private Bool
diff --git a/modules/im/ximcp/imDefIm.c b/modules/im/ximcp/imDefIm.c
index 95e267ce..a2f81eea 100644
--- a/modules/im/ximcp/imDefIm.c
+++ b/modules/im/ximcp/imDefIm.c
@@ -1587,7 +1587,7 @@ _XimGetEncoding(
XlcNCompoundText, lcd, XlcNWideChar)))
return False;
if (!(ctoutf8_conv = _XlcOpenConverter(lcd,
- XlcNCompoundText, lcd, XFree86lcNUtf8String)))
+ XlcNCompoundText, lcd, XlcNUtf8String)))
return False;
}
@@ -1602,7 +1602,7 @@ _XimGetEncoding(
XlcNCompoundText, lcd, XlcNWideChar)))
return False;
if (!(ctoutf8_conv = _XlcOpenConverter(lcd,
- XlcNCompoundText, lcd, XFree86lcNUtf8String)))
+ XlcNCompoundText, lcd, XlcNUtf8String)))
return False;
break;
} else {
@@ -1634,7 +1634,7 @@ _XimGetEncoding(
return False;
private->cstowc_conv = conv;
- if (!(conv = _XlcOpenConverter(lcd, XlcNCharSet, lcd, XFree86lcNUtf8String)))
+ if (!(conv = _XlcOpenConverter(lcd, XlcNCharSet, lcd, XlcNUtf8String)))
return False;
private->cstoutf8_conv = conv;
@@ -1642,7 +1642,7 @@ _XimGetEncoding(
return False;
private->ucstoc_conv = conv;
- if (!(conv = _XlcOpenConverter(lcd, XlcNUcsChar, lcd, XFree86lcNUtf8String)))
+ if (!(conv = _XlcOpenConverter(lcd, XlcNUcsChar, lcd, XlcNUtf8String)))
return False;
private->ucstoutf8_conv = conv;
diff --git a/modules/im/ximcp/imDefLkup.c b/modules/im/ximcp/imDefLkup.c
index 4a27db6a..fda84cb7 100644
--- a/modules/im/ximcp/imDefLkup.c
+++ b/modules/im/ximcp/imDefLkup.c
@@ -1105,7 +1105,7 @@ _XimProtoWcLookupString(
}
Public int
-_XFree86imProtoUtf8LookupString(
+_XimProtoUtf8LookupString(
XIC xic,
XKeyEvent *ev,
char *buffer,
@@ -1145,7 +1145,7 @@ _XFree86imProtoUtf8LookupString(
_XimUnregCommitInfo(ic);
} else if (ev->type == KeyPress) {
- ret = _XFree86imLookupUtf8Text(ic, ev, buffer, bytes, keysym, NULL);
+ ret = _XimLookupUTF8Text(ic, ev, buffer, bytes, keysym, NULL);
if (ret > 0) {
if (ret > bytes)
*state = XBufferOverflow;
diff --git a/modules/im/ximcp/imLcIc.c b/modules/im/ximcp/imLcIc.c
index 344cd4fc..9a65d3db 100644
--- a/modules/im/ximcp/imLcIc.c
+++ b/modules/im/ximcp/imLcIc.c
@@ -125,7 +125,7 @@ Private XICMethodsRec Local_ic_methods = {
_XimLocalMbReset, /* utf8_reset */
_XimLocalMbLookupString, /* mb_lookup_string */
_XimLocalWcLookupString, /* wc_lookup_string */
- _XFree86imLocalUtf8LookupString /* utf8_lookup_string */
+ _XimLocalUtf8LookupString /* utf8_lookup_string */
};
Public XIC
diff --git a/modules/im/ximcp/imLcIm.c b/modules/im/ximcp/imLcIm.c
index d6ea9209..b049bb7f 100644
--- a/modules/im/ximcp/imLcIm.c
+++ b/modules/im/ximcp/imLcIm.c
@@ -300,7 +300,7 @@ _XimLocalOpenIM(
goto Open_Error;
private->ctow_conv = conv;
- if (!(conv = _XlcOpenConverter(lcd, XlcNCompoundText, lcd, XFree86lcNUtf8String)))
+ if (!(conv = _XlcOpenConverter(lcd, XlcNCompoundText, lcd, XlcNUtf8String)))
goto Open_Error;
private->ctoutf8_conv = conv;
@@ -312,7 +312,7 @@ _XimLocalOpenIM(
goto Open_Error;
private->cstowc_conv = conv;
- if (!(conv = _XlcOpenConverter(lcd, XlcNCharSet, lcd, XFree86lcNUtf8String)))
+ if (!(conv = _XlcOpenConverter(lcd, XlcNCharSet, lcd, XlcNUtf8String)))
goto Open_Error;
private->cstoutf8_conv = conv;
@@ -320,7 +320,7 @@ _XimLocalOpenIM(
goto Open_Error;
private->ucstoc_conv = conv;
- if (!(conv = _XlcOpenConverter(lcd, XlcNUcsChar, lcd, XFree86lcNUtf8String)))
+ if (!(conv = _XlcOpenConverter(lcd, XlcNUcsChar, lcd, XlcNUtf8String)))
goto Open_Error;
private->ucstoutf8_conv = conv;
diff --git a/modules/im/ximcp/imLcLkup.c b/modules/im/ximcp/imLcLkup.c
index ea1d84d0..f3399aa0 100644
--- a/modules/im/ximcp/imLcLkup.c
+++ b/modules/im/ximcp/imLcLkup.c
@@ -161,7 +161,7 @@ _XimLocalWcLookupString(xic, ev, buffer, wlen, keysym, status)
}
Public int
-_XFree86imLocalUtf8LookupString(xic, ev, buffer, bytes, keysym, status)
+_XimLocalUtf8LookupString(xic, ev, buffer, bytes, keysym, status)
XIC xic;
XKeyEvent *ev;
char *buffer;
@@ -199,7 +199,7 @@ _XFree86imLocalUtf8LookupString(xic, ev, buffer, bytes, keysym, status)
}
return (ret);
} else { /* Throughed Event */
- ret = _XFree86imLookupUtf8Text(ic, ev, buffer, bytes, keysym, NULL);
+ ret = _XimLookupUTF8Text(ic, ev, buffer, bytes, keysym, NULL);
if(ret > 0) {
if (ret > bytes) {
if (status) *status = XBufferOverflow;
diff --git a/modules/im/ximcp/imLcPrs.c b/modules/im/ximcp/imLcPrs.c
index e4a08913..f00d0741 100644
--- a/modules/im/ximcp/imLcPrs.c
+++ b/modules/im/ximcp/imLcPrs.c
@@ -47,7 +47,7 @@ extern int _Xmbstowcs(
int len
);
-extern int _XFree86mbstoutf8(
+extern int _Xmbstoutf8(
char *ustr,
const char *str,
int len
@@ -584,7 +584,7 @@ parseline(
}
memcpy((char *)rhs_string_wc, (char *)local_wc_buf, (l + 1) * sizeof(wchar_t) );
- l = _XFree86mbstoutf8(local_utf8_buf, rhs_string_mb, LOCAL_UTF8_BUFSIZE - 1);
+ l = _Xmbstoutf8(local_utf8_buf, rhs_string_mb, LOCAL_UTF8_BUFSIZE - 1);
if (l == LOCAL_UTF8_BUFSIZE - 1) {
local_wc_buf[l] = '\0';
}
diff --git a/modules/im/ximcp/imThaiFlt.c b/modules/im/ximcp/imThaiFlt.c
index 684f5f48..02eb7a86 100644
--- a/modules/im/ximcp/imThaiFlt.c
+++ b/modules/im/ximcp/imThaiFlt.c
@@ -1358,7 +1358,7 @@ XPointer client_data;
_Xlcwcstombs(ic->core.im->core.lcd, ic->private.local.composed->mb,
ic->private.local.composed->wc, 10);
- _XFree86lcmbstoutf8(ic->core.im->core.lcd, ic->private.local.composed->utf8,
+ _Xlcmbstoutf8(ic->core.im->core.lcd, ic->private.local.composed->utf8,
ic->private.local.composed->mb, 10);
/* Remember the last character inputted
diff --git a/modules/im/ximcp/imThaiIc.c b/modules/im/ximcp/imThaiIc.c
index ff9215ec..b67e9c14 100644
--- a/modules/im/ximcp/imThaiIc.c
+++ b/modules/im/ximcp/imThaiIc.c
@@ -138,7 +138,7 @@ Private XICMethodsRec Thai_ic_methods = {
_XimThaiMbReset, /* utf8_reset */
_XimLocalMbLookupString, /* mb_lookup_string */
_XimLocalWcLookupString, /* wc_lookup_string */
- _XFree86imLocalUtf8LookupString /* utf8_lookup_string */
+ _XimLocalUtf8LookupString /* utf8_lookup_string */
};
XIC
diff --git a/modules/im/ximcp/imThaiIm.c b/modules/im/ximcp/imThaiIm.c
index 75868531..23d3a8e8 100644
--- a/modules/im/ximcp/imThaiIm.c
+++ b/modules/im/ximcp/imThaiIm.c
@@ -106,7 +106,7 @@ _XimThaiOpenIM(im)
goto Open_Error;
private->ctow_conv = conv;
- if (!(conv = _XlcOpenConverter(lcd, XlcNCompoundText, lcd, XFree86lcNUtf8String)))
+ if (!(conv = _XlcOpenConverter(lcd, XlcNCompoundText, lcd, XlcNUtf8String)))
goto Open_Error;
private->ctoutf8_conv = conv;
@@ -118,7 +118,7 @@ _XimThaiOpenIM(im)
goto Open_Error;
private->cstowc_conv = conv;
- if (!(conv = _XlcOpenConverter(lcd, XlcNCharSet, lcd, XFree86lcNUtf8String)))
+ if (!(conv = _XlcOpenConverter(lcd, XlcNCharSet, lcd, XlcNUtf8String)))
goto Open_Error;
private->cstoutf8_conv = conv;
@@ -126,7 +126,7 @@ _XimThaiOpenIM(im)
goto Open_Error;
private->ucstoc_conv = conv;
- if (!(conv = _XlcOpenConverter(lcd, XlcNUcsChar, lcd, XFree86lcNUtf8String)))
+ if (!(conv = _XlcOpenConverter(lcd, XlcNUcsChar, lcd, XlcNUtf8String)))
goto Open_Error;
private->ucstoutf8_conv = conv;
diff --git a/modules/lc/Utf8/lcUTF8Load.c b/modules/lc/Utf8/lcUTF8Load.c
index 68dbbdc8..e4fffac0 100644
--- a/modules/lc/Utf8/lcUTF8Load.c
+++ b/modules/lc/Utf8/lcUTF8Load.c
@@ -54,8 +54,8 @@ _XlcUtf8Loader(
return (XLCd) NULL;
}
- _XFree86lcAddUtf8LocaleConverters(lcd);
- _XFree86lcAddUtf8Converters(lcd);
+ _XlcAddUtf8LocaleConverters(lcd);
+ _XlcAddUtf8Converters(lcd);
return lcd;
}
diff --git a/modules/lc/def/lcDefConv.c b/modules/lc/def/lcDefConv.c
index 0016991a..cbcf087f 100644
--- a/modules/lc/def/lcDefConv.c
+++ b/modules/lc/def/lcDefConv.c
@@ -784,7 +784,7 @@ _XlcDefaultLoader(
_XlcSetConverter(lcd, XlcNCharSet, lcd, XlcNMultiByte, open_cstombs);
_XlcSetConverter(lcd, XlcNCharSet, lcd, XlcNWideChar, open_cstowcs);
- _XFree86lcAddUtf8Converters(lcd);
+ _XlcAddUtf8Converters(lcd);
return lcd;
}
diff --git a/modules/lc/gen/lcGenConv.c b/modules/lc/gen/lcGenConv.c
index 1219bb57..bac71d41 100644
--- a/modules/lc/gen/lcGenConv.c
+++ b/modules/lc/gen/lcGenConv.c
@@ -3142,7 +3142,7 @@ _XlcGenericLoader(
}
#endif
- _XFree86lcAddUtf8Converters(lcd);
+ _XlcAddUtf8Converters(lcd);
return lcd;
}
diff --git a/modules/lc/xlocale/lcEuc.c b/modules/lc/xlocale/lcEuc.c
index 6df1d412..26f93acc 100644
--- a/modules/lc/xlocale/lcEuc.c
+++ b/modules/lc/xlocale/lcEuc.c
@@ -1488,7 +1488,7 @@ _XlcEucLoader(
_XlcSetConverter(lcd, XlcNWideChar, lcd, XlcNMultiByte, open_wcstombs);
#endif
- _XFree86lcAddUtf8Converters(lcd);
+ _XlcAddUtf8Converters(lcd);
return lcd;
}
diff --git a/modules/lc/xlocale/lcJis.c b/modules/lc/xlocale/lcJis.c
index ae23d96a..161dbb28 100644
--- a/modules/lc/xlocale/lcJis.c
+++ b/modules/lc/xlocale/lcJis.c
@@ -934,7 +934,7 @@ _XlcJisLoader(
}
#endif
- _XFree86lcAddUtf8Converters(lcd);
+ _XlcAddUtf8Converters(lcd);
return lcd;
}
diff --git a/modules/lc/xlocale/lcSjis.c b/modules/lc/xlocale/lcSjis.c
index cc629eb1..29e7e19e 100644
--- a/modules/lc/xlocale/lcSjis.c
+++ b/modules/lc/xlocale/lcSjis.c
@@ -1556,7 +1556,7 @@ _XlcSjisLoader(
_XlcSetConverter(lcd, XlcNWideChar, lcd, XlcNMultiByte, open_wcstombs);
#endif
- _XFree86lcAddUtf8Converters(lcd);
+ _XlcAddUtf8Converters(lcd);
return lcd;
}
diff --git a/modules/om/generic/omDefault.c b/modules/om/generic/omDefault.c
index c711604b..806ad5ce 100644
--- a/modules/om/generic/omDefault.c
+++ b/modules/om/generic/omDefault.c
@@ -73,7 +73,7 @@ utf8_to_mbs(
XlcConv conv;
int to_left, ret;
- conv = _XomInitConverter(oc, XFree86OMUtf8String);
+ conv = _XomInitConverter(oc, XOMUtf8String);
if (conv == NULL)
return False;
@@ -116,7 +116,7 @@ err:
}
int
-_XFree86utf8DefaultTextEscapement(XOC oc, _Xconst char *text, int length)
+_Xutf8DefaultTextEscapement(XOC oc, _Xconst char *text, int length)
{
DefineLocalBuf;
char *buf = AllocLocalBuf(length);
@@ -190,9 +190,8 @@ err:
}
int
-_XFree86utf8DefaultTextExtents(XOC oc, _Xconst char *text, int length,
- XRectangle *overall_ink,
- XRectangle *overall_logical)
+_Xutf8DefaultTextExtents(XOC oc, _Xconst char *text, int length,
+ XRectangle *overall_ink, XRectangle *overall_logical)
{
DefineLocalBuf;
char *buf = AllocLocalBuf(length);
@@ -314,12 +313,11 @@ err:
}
Status
-_XFree86utf8DefaultTextPerCharExtents(XOC oc, _Xconst char *text, int length,
- XRectangle *ink_buf,
- XRectangle *logical_buf,
- int buf_size, int *num_chars,
- XRectangle *overall_ink,
- XRectangle *overall_logical)
+_Xutf8DefaultTextPerCharExtents(XOC oc, _Xconst char *text, int length,
+ XRectangle *ink_buf, XRectangle *logical_buf,
+ int buf_size, int *num_chars,
+ XRectangle *overall_ink,
+ XRectangle *overall_logical)
{
DefineLocalBuf;
char *buf = AllocLocalBuf(length);
@@ -380,8 +378,8 @@ err:
}
int
-_XFree86utf8DefaultDrawString(Display *dpy, Drawable d, XOC oc, GC gc,
- int x, int y, _Xconst char *text, int length)
+_Xutf8DefaultDrawString(Display *dpy, Drawable d, XOC oc, GC gc, int x, int y,
+ _Xconst char *text, int length)
{
DefineLocalBuf;
char *buf = AllocLocalBuf(length);
@@ -431,8 +429,8 @@ err:
}
void
-_XFree86utf8DefaultDrawImageString(Display *dpy, Drawable d, XOC oc, GC gc,
- int x, int y, _Xconst char *text, int length)
+_Xutf8DefaultDrawImageString(Display *dpy, Drawable d, XOC oc, GC gc, int x,
+ int y, _Xconst char *text, int length)
{
DefineLocalBuf;
char *buf = AllocLocalBuf(length);
diff --git a/modules/om/generic/omGeneric.c b/modules/om/generic/omGeneric.c
index f1206595..331c2aa5 100644
--- a/modules/om/generic/omGeneric.c
+++ b/modules/om/generic/omGeneric.c
@@ -66,26 +66,26 @@
#if 0
extern int _XmbDefaultTextEscapement(), _XwcDefaultTextEscapement(),
- _XFree86utf8DefaultTextEscapement();
+ _Xutf8DefaultTextEscapement();
extern int _XmbDefaultTextExtents(), _XwcDefaultTextExtents(),
- _XFree86utf8DefaultTextExtents();
+ _Xutf8DefaultTextExtents();
extern Status _XmbDefaultTextPerCharExtents(), _XwcDefaultTextPerCharExtents(),
- _XFree86utf8DefaultTextPerCharExtents();
+ _Xutf8DefaultTextPerCharExtents();
extern int _XmbDefaultDrawString(), _XwcDefaultDrawString(),
- _XFree86utf8DefaultDrawString();
+ _Xutf8DefaultDrawString();
extern void _XmbDefaultDrawImageString(), _XwcDefaultDrawImageString(),
- _XFree86utf8DefaultDrawImageString();
+ _Xutf8DefaultDrawImageString();
extern int _XmbGenericTextEscapement(), _XwcGenericTextEscapement(),
- _XFree86utf8GenericTextEscapement();
+ _Xutf8GenericTextEscapement();
extern int _XmbGenericTextExtents(), _XwcGenericTextExtents(),
- _XFree86utf8GenericTextExtents();
+ _Xutf8GenericTextExtents();
extern Status _XmbGenericTextPerCharExtents(), _XwcGenericTextPerCharExtents(),
- _XFree86utf8GenericTextPerCharExtents();
+ _Xutf8GenericTextPerCharExtents();
extern int _XmbGenericDrawString(), _XwcGenericDrawString(),
- _XFree86utf8GenericDrawString();
+ _Xutf8GenericDrawString();
extern void _XmbGenericDrawImageString(), _XwcGenericDrawImageString(),
- _XFree86utf8GenericDrawImageString();
+ _Xutf8GenericDrawImageString();
extern void _XlcDbg_printValue (const char *str, char **value, int num);
#endif
@@ -1583,11 +1583,11 @@ static XOCMethodsRec oc_default_methods = {
_XwcDefaultTextPerCharExtents,
_XwcDefaultDrawString,
_XwcDefaultDrawImageString,
- _XFree86utf8DefaultTextEscapement,
- _XFree86utf8DefaultTextExtents,
- _XFree86utf8DefaultTextPerCharExtents,
- _XFree86utf8DefaultDrawString,
- _XFree86utf8DefaultDrawImageString
+ _Xutf8DefaultTextEscapement,
+ _Xutf8DefaultTextExtents,
+ _Xutf8DefaultTextPerCharExtents,
+ _Xutf8DefaultDrawString,
+ _Xutf8DefaultDrawImageString
};
static XOCMethodsRec oc_generic_methods = {
@@ -1604,11 +1604,11 @@ static XOCMethodsRec oc_generic_methods = {
_XwcGenericTextPerCharExtents,
_XwcGenericDrawString,
_XwcGenericDrawImageString,
- _XFree86utf8GenericTextEscapement,
- _XFree86utf8GenericTextExtents,
- _XFree86utf8GenericTextPerCharExtents,
- _XFree86utf8GenericDrawString,
- _XFree86utf8GenericDrawImageString
+ _Xutf8GenericTextEscapement,
+ _Xutf8GenericTextExtents,
+ _Xutf8GenericTextPerCharExtents,
+ _Xutf8GenericDrawString,
+ _Xutf8GenericDrawImageString
};
typedef struct _XOCMethodsListRec {
diff --git a/modules/om/generic/omImText.c b/modules/om/generic/omImText.c
index 1dff788f..30667868 100644
--- a/modules/om/generic/omImText.c
+++ b/modules/om/generic/omImText.c
@@ -81,9 +81,9 @@ _XwcGenericDrawImageString(Display *dpy, Drawable d, XOC oc, GC gc, int x,
}
void
-_XFree86utf8GenericDrawImageString(Display *dpy, Drawable d, XOC oc, GC gc,
- int x, int y, _Xconst char *text, int length)
+_Xutf8GenericDrawImageString(Display *dpy, Drawable d, XOC oc, GC gc, int x,
+ int y, _Xconst char *text, int length)
{
- _XomGenericDrawImageString(dpy, d, oc, gc, x, y, XFree86OMUtf8String,
+ _XomGenericDrawImageString(dpy, d, oc, gc, x, y, XOMUtf8String,
(XPointer) text, length);
}
diff --git a/modules/om/generic/omText.c b/modules/om/generic/omText.c
index 46d529fc..6d6c41f8 100644
--- a/modules/om/generic/omText.c
+++ b/modules/om/generic/omText.c
@@ -361,9 +361,9 @@ _XwcGenericDrawString(Display *dpy, Drawable d, XOC oc, GC gc, int x, int y,
}
int
-_XFree86utf8GenericDrawString(Display *dpy, Drawable d, XOC oc, GC gc,
- int x, int y, _Xconst char *text, int length)
+_Xutf8GenericDrawString(Display *dpy, Drawable d, XOC oc, GC gc, int x, int y,
+ _Xconst char *text, int length)
{
- return _XomGenericDrawString(dpy, d, oc, gc, x, y, XFree86OMUtf8String,
+ return _XomGenericDrawString(dpy, d, oc, gc, x, y, XOMUtf8String,
(XPointer) text, length);
}
diff --git a/modules/om/generic/omTextEsc.c b/modules/om/generic/omTextEsc.c
index 088132b6..84ccbf3a 100644
--- a/modules/om/generic/omTextEsc.c
+++ b/modules/om/generic/omTextEsc.c
@@ -292,8 +292,8 @@ _XwcGenericTextEscapement(XOC oc, _Xconst wchar_t *text, int length)
}
int
-_XFree86utf8GenericTextEscapement(XOC oc, _Xconst char *text, int length)
+_Xutf8GenericTextEscapement(XOC oc, _Xconst char *text, int length)
{
- return _XomGenericTextEscapement(oc, XFree86OMUtf8String, (XPointer) text,
+ return _XomGenericTextEscapement(oc, XOMUtf8String, (XPointer) text,
length);
}
diff --git a/modules/om/generic/omTextExt.c b/modules/om/generic/omTextExt.c
index ddff807e..275df91c 100644
--- a/modules/om/generic/omTextExt.c
+++ b/modules/om/generic/omTextExt.c
@@ -126,9 +126,9 @@ _XwcGenericTextExtents(XOC oc, _Xconst wchar_t *text, int length,
}
int
-_XFree86utf8GenericTextExtents(XOC oc, _Xconst char *text, int length,
+_Xutf8GenericTextExtents(XOC oc, _Xconst char *text, int length,
XRectangle *overall_ink, XRectangle *overall_logical)
{
- return _XomGenericTextExtents(oc, XFree86OMUtf8String, (XPointer) text,
- length, overall_ink, overall_logical);
+ return _XomGenericTextExtents(oc, XOMUtf8String, (XPointer) text, length,
+ overall_ink, overall_logical);
}
diff --git a/modules/om/generic/omTextPer.c b/modules/om/generic/omTextPer.c
index 521e31fd..d6dec28f 100644
--- a/modules/om/generic/omTextPer.c
+++ b/modules/om/generic/omTextPer.c
@@ -188,15 +188,14 @@ _XwcGenericTextPerCharExtents(XOC oc, _Xconst wchar_t *text, int length,
}
Status
-_XFree86utf8GenericTextPerCharExtents(XOC oc, _Xconst char *text, int length,
- XRectangle *ink_buf,
- XRectangle *logical_buf,
- int buf_size, int *num_chars,
- XRectangle *overall_ink,
- XRectangle *overall_logical)
+_Xutf8GenericTextPerCharExtents(XOC oc, _Xconst char *text, int length,
+ XRectangle *ink_buf, XRectangle *logical_buf,
+ int buf_size, int *num_chars,
+ XRectangle *overall_ink,
+ XRectangle *overall_logical)
{
- return _XomGenericTextPerCharExtents(oc, XFree86OMUtf8String,
- (XPointer) text, length, ink_buf,
- logical_buf, buf_size, num_chars,
- overall_ink, overall_logical);
+ return _XomGenericTextPerCharExtents(oc, XOMUtf8String, (XPointer) text,
+ length, ink_buf, logical_buf, buf_size,
+ num_chars, overall_ink,
+ overall_logical);
}
diff --git a/modules/om/generic/omXChar.c b/modules/om/generic/omXChar.c
index e05ba3f1..87148063 100644
--- a/modules/om/generic/omXChar.c
+++ b/modules/om/generic/omXChar.c
@@ -448,9 +448,9 @@ _XomInitConverter(
convp = &gen->mbs_to_cs;
conv_type = XlcNMultiByte;
break;
- case XFree86OMUtf8String:
+ case XOMUtf8String:
convp = &gen->utf8_to_cs;
- conv_type = XFree86lcNUtf8String;
+ conv_type = XlcNUtf8String;
break;
default:
return (XlcConv) NULL;
diff --git a/src/XomGeneric.h b/src/XomGeneric.h
index 85f25ff6..9b547495 100644
--- a/src/XomGeneric.h
+++ b/src/XomGeneric.h
@@ -61,7 +61,7 @@ typedef struct _VRotateRec {
typedef enum {
XOMMultiByte,
XOMWideChar,
- XFree86OMUtf8String
+ XOMUtf8String
} XOMTextType;
typedef struct _FontDataRec {
@@ -178,7 +178,7 @@ _XmbDefaultTextEscapement(XOC oc, _Xconst char *text, int length);
extern int
_XwcDefaultTextEscapement(XOC oc, _Xconst wchar_t *text, int length);
extern int
-_XFree86utf8DefaultTextEscapement(XOC oc, _Xconst char *text, int length);
+_Xutf8DefaultTextEscapement(XOC oc, _Xconst char *text, int length);
extern int
_XmbDefaultTextExtents(XOC oc, _Xconst char *text, int length,
XRectangle *overall_ink, XRectangle *overall_logical);
@@ -186,7 +186,7 @@ extern int
_XwcDefaultTextExtents(XOC oc, _Xconst wchar_t *text, int length,
XRectangle *overall_ink, XRectangle *overall_logical);
extern int
-_XFree86utf8DefaultTextExtents(XOC oc, _Xconst char *text, int length,
+_Xutf8DefaultTextExtents(XOC oc, _Xconst char *text, int length,
XRectangle *overall_ink, XRectangle *overall_logical);
extern Status
_XmbDefaultTextPerCharExtents(
@@ -203,7 +203,7 @@ _XwcDefaultTextPerCharExtents(
XRectangle *overall_ink,
XRectangle *overall_logical);
extern Status
-_XFree86utf8DefaultTextPerCharExtents(
+_Xutf8DefaultTextPerCharExtents(
XOC oc, _Xconst char *text, int length,
XRectangle *ink_buf, XRectangle *logical_buf,
int buf_size, int *num_chars,
@@ -216,8 +216,8 @@ extern int
_XwcDefaultDrawString(Display *dpy, Drawable d, XOC oc, GC gc, int x, int y,
_Xconst wchar_t *text, int length);
extern int
-_XFree86utf8DefaultDrawString(Display *dpy, Drawable d, XOC oc, GC gc,
- int x, int y, _Xconst char *text, int length);
+_Xutf8DefaultDrawString(Display *dpy, Drawable d, XOC oc, GC gc, int x, int y,
+ _Xconst char *text, int length);
extern void
_XmbDefaultDrawImageString(Display *dpy, Drawable d, XOC oc, GC gc, int x,
int y, _Xconst char *text, int length);
@@ -225,8 +225,8 @@ extern void
_XwcDefaultDrawImageString(Display *dpy, Drawable d, XOC oc, GC gc, int x,
int y, _Xconst wchar_t *text, int length);
extern void
-_XFree86utf8DefaultDrawImageString(Display *dpy, Drawable d, XOC oc, GC gc,
- int x, int y, _Xconst char *text, int length);
+_Xutf8DefaultDrawImageString(Display *dpy, Drawable d, XOC oc, GC gc, int x,
+ int y, _Xconst char *text, int length);
extern int
_XmbGenericTextEscapement(XOC oc, _Xconst char *text, int length);
@@ -234,23 +234,23 @@ extern int
_XmbGenericTextExtents(XOC oc, _Xconst char *text, int length,
XRectangle *overall_ink, XRectangle *overall_logical);
extern int
-_XFree86utf8GenericDrawString(Display *dpy, Drawable d, XOC oc, GC gc,
- int x, int y, _Xconst char *text, int length);
+_Xutf8GenericDrawString(Display *dpy, Drawable d, XOC oc, GC gc, int x, int y,
+ _Xconst char *text, int length);
extern void
-_XFree86utf8GenericDrawImageString(Display *dpy, Drawable d, XOC oc, GC gc,
- int x, int y, _Xconst char *text, int length);
+_Xutf8GenericDrawImageString(Display *dpy, Drawable d, XOC oc, GC gc, int x,
+ int y, _Xconst char *text, int length);
extern Status
-_XFree86utf8GenericTextPerCharExtents(
+_Xutf8GenericTextPerCharExtents(
XOC oc, _Xconst char *text, int length,
XRectangle *ink_buf, XRectangle *logical_buf,
int buf_size, int *num_chars,
XRectangle *overall_ink,
XRectangle *overall_logical);
extern int
-_XFree86utf8GenericTextExtents(XOC oc, _Xconst char *text, int length,
+_Xutf8GenericTextExtents(XOC oc, _Xconst char *text, int length,
XRectangle *overall_ink, XRectangle *overall_logical);
extern int
-_XFree86utf8GenericTextEscapement(XOC oc, _Xconst char *text, int length);
+_Xutf8GenericTextEscapement(XOC oc, _Xconst char *text, int length);
extern void
_XwcGenericDrawImageString(Display *dpy, Drawable d, XOC oc, GC gc, int x,
int y, _Xconst wchar_t *text, int length);
diff --git a/src/imConv.c b/src/imConv.c
index d3a87a42..b77eaae7 100644
--- a/src/imConv.c
+++ b/src/imConv.c
@@ -84,12 +84,12 @@ XPointer
_XimGetLocaleCode (
_Xconst char* encoding_name)
{
- XPointer cvt = _XFree86utf8GetConvByName(encoding_name);
+ XPointer cvt = _Utf8GetConvByName(encoding_name);
if (!cvt && encoding_name) {
int i;
for (i = 0; i < num_substitute; i++)
if (!strcmp(encoding_name, SubstTable[i].encoding_name))
- return _XFree86utf8GetConvByName(SubstTable[i].charset_name);
+ return _Utf8GetConvByName(SubstTable[i].charset_name);
}
return cvt;
}
@@ -298,7 +298,7 @@ _XimLookupWCText(ic, event, buffer, nbytes, keysym, status)
}
int
-_XFree86imLookupUtf8Text(ic, event, buffer, nbytes, keysym, status)
+_XimLookupUTF8Text(ic, event, buffer, nbytes, keysym, status)
Xic ic;
XKeyEvent* event;
char* buffer;
diff --git a/src/xlibi18n/ICWrap.c b/src/xlibi18n/ICWrap.c
index 57a0ad55..01bfb9e3 100644
--- a/src/xlibi18n/ICWrap.c
+++ b/src/xlibi18n/ICWrap.c
@@ -391,7 +391,8 @@ XwcResetIC(ic)
}
char *
-XFree86utf8ResetIC(XIC ic)
+Xutf8ResetIC(ic)
+ XIC ic;
{
if (ic->core.im) {
if (ic->methods->utf8_reset)
@@ -402,15 +403,6 @@ XFree86utf8ResetIC(XIC ic)
return (char *)NULL;
}
-#ifndef NOXFREE86COMPAT
-#undef Xutf8ResetIC
-char *
-Xutf8ResetIC(XIC ic)
-{
- return XFree86utf8ResetIC(ic);
-}
-#endif
-
int
XmbLookupString(ic, ev, buffer, nbytes, keysym, status)
XIC ic;
@@ -442,13 +434,13 @@ XwcLookupString(ic, ev, buffer, nchars, keysym, status)
}
int
-XFree86utf8LookupString(
- XIC ic,
- register XKeyEvent *ev,
- char *buffer,
- int nbytes,
- KeySym *keysym,
- Status *status)
+Xutf8LookupString(ic, ev, buffer, nbytes, keysym, status)
+ XIC ic;
+ register XKeyEvent *ev;
+ char *buffer;
+ int nbytes;
+ KeySym *keysym;
+ Status *status;
{
if (ic->core.im) {
if (ic->methods->utf8_lookup_string)
@@ -460,18 +452,3 @@ XFree86utf8LookupString(
}
return XLookupNone;
}
-
-#ifndef NOXFREE86COMPAT
-#undef Xutf8LookupString
-int
-Xutf8LookupString(
- XIC ic,
- register XKeyEvent *ev,
- char *buffer,
- int nbytes,
- KeySym *keysym,
- Status *status)
-{
- return XFree86utf8LookupString(ic, ev, buffer, nbytes, keysym, status);
-}
-#endif
diff --git a/src/xlibi18n/Ximint.h b/src/xlibi18n/Ximint.h
index d52e4fdb..3809c658 100644
--- a/src/xlibi18n/Ximint.h
+++ b/src/xlibi18n/Ximint.h
@@ -705,7 +705,7 @@ extern int _XimProtoWcLookupString(
Status *state
);
-extern int _XFree86imProtoUtf8LookupString(
+extern int _XimProtoUtf8LookupString(
XIC xic,
XKeyEvent *ev,
char *buffer,
@@ -764,7 +764,7 @@ extern int _XimLookupWCText(
XComposeStatus *status
);
-extern int _XFree86imLookupUtf8Text(
+extern int _XimLookupUTF8Text(
Xic ic,
XKeyEvent *event,
char *buffer,
@@ -915,7 +915,7 @@ extern int _XimLocalWcLookupString(
Status *status
);
-extern int _XFree86imLocalUtf8LookupString(
+extern int _XimLocalUtf8LookupString(
XIC ic,
XKeyEvent *ev,
char *buffer,
diff --git a/src/xlibi18n/XlcPubI.h b/src/xlibi18n/XlcPubI.h
index ad2ade50..86a1792f 100644
--- a/src/xlibi18n/XlcPubI.h
+++ b/src/xlibi18n/XlcPubI.h
@@ -156,7 +156,7 @@ extern int _XwcTextPropertyToTextList(
int* count_ret
);
-extern int _XFree86utf8TextPropertyToTextList(
+extern int _Xutf8TextPropertyToTextList(
XLCd lcd,
Display* dpy,
const XTextProperty* text_prop,
@@ -182,7 +182,7 @@ extern int _XwcTextListToTextProperty(
XTextProperty* /* text_prop */
);
-extern int _XFree86utf8TextListToTextProperty(
+extern int _Xutf8TextListToTextProperty(
XLCd /* lcd */,
Display* /* dpy */,
char** /* list */,
@@ -246,12 +246,12 @@ extern char *_XlcMapOSLocaleName(
#endif
extern int
-_XFree86mbstoutf8(
+_Xmbstoutf8(
char *ustr,
const char *str,
int len);
extern int
-_XFree86lcmbstoutf8(
+_Xlcmbstoutf8(
XLCd lcd,
char *ustr,
const char *str,
@@ -293,7 +293,7 @@ _Xlcwctomb(
extern XPointer
-_XFree86utf8GetConvByName(
+_Utf8GetConvByName(
const char *name);
_XFUNCPROTOEND
diff --git a/src/xlibi18n/XlcPublic.h b/src/xlibi18n/XlcPublic.h
index 1a328c4c..72df4c8e 100644
--- a/src/xlibi18n/XlcPublic.h
+++ b/src/xlibi18n/XlcPublic.h
@@ -206,7 +206,7 @@ typedef struct _XlcConvMethodsRec{
#define XlcNWideChar "wideChar"
#define XlcNCompoundText "compoundText"
#define XlcNString "string"
-#define XFree86lcNUtf8String "utf8String"
+#define XlcNUtf8String "utf8String"
#define XlcNCharSet "charSet"
#define XlcNCTCharSet "CTcharSet"
#define XlcNFontCharSet "FontCharSet"
diff --git a/src/xlibi18n/Xlcint.h b/src/xlibi18n/Xlcint.h
index 85dcc898..fe3b8c95 100644
--- a/src/xlibi18n/Xlcint.h
+++ b/src/xlibi18n/Xlcint.h
@@ -903,12 +903,12 @@ extern void _XlcRemoveLoader(
);
/* Registers UTF-8 converters for a non-UTF-8 locale. */
-extern void _XFree86lcAddUtf8Converters(
+extern void _XlcAddUtf8Converters(
XLCd lcd
);
/* Registers UTF-8 converters for a UTF-8 locale. */
-extern void _XFree86lcAddUtf8LocaleConverters(
+extern void _XlcAddUtf8LocaleConverters(
XLCd lcd
);
diff --git a/src/xlibi18n/lcPrTxt.c b/src/xlibi18n/lcPrTxt.c
index 23253dab..9078b9be 100644
--- a/src/xlibi18n/lcPrTxt.c
+++ b/src/xlibi18n/lcPrTxt.c
@@ -139,7 +139,7 @@ _XTextPropertyToTextList(
if (encoding == XA_STRING)
from_type = XlcNString;
else if (encoding == XInternAtom(dpy, "UTF8_STRING", False))
- from_type = XFree86lcNUtf8String;
+ from_type = XlcNUtf8String;
else if (encoding == XInternAtom(dpy, "COMPOUND_TEXT", False))
from_type = XlcNCompoundText;
else if (encoding == XInternAtom(dpy, XLC_PUBLIC(lcd, encoding_name), False))
@@ -150,7 +150,7 @@ _XTextPropertyToTextList(
if (is_wide_char) {
buf_len = (text_prop->nitems + 1) * sizeof(wchar_t);;
} else {
- if (strcmp(to_type, XFree86lcNUtf8String) == 0)
+ if (strcmp(to_type, XlcNUtf8String) == 0)
buf_len = text_prop->nitems * 6 + 1;
else
buf_len = text_prop->nitems * XLC_PUBLIC(lcd, mb_cur_max) + 1;
@@ -162,7 +162,7 @@ _XTextPropertyToTextList(
to_left = buf_len;
/* can be XlcNMultiByte to XlcNMultiByte,
- or XFree86lcNUtf8String to XFree86lcNUtf8String */
+ or XlcNUtf8String to XlcNUtf8String */
if (!strcmp(from_type, to_type)) {
do_strcpy = True;
} else {
@@ -265,14 +265,14 @@ _XwcTextPropertyToTextList(
}
int
-_XFree86utf8TextPropertyToTextList(
+_Xutf8TextPropertyToTextList(
XLCd lcd,
Display *dpy,
const XTextProperty *text_prop,
char ***list_ret,
int *count_ret)
{
- return _XTextPropertyToTextList(lcd, dpy, text_prop, XFree86lcNUtf8String,
+ return _XTextPropertyToTextList(lcd, dpy, text_prop, XlcNUtf8String,
(XPointer **) list_ret, count_ret);
}
diff --git a/src/xlibi18n/lcPublic.c b/src/xlibi18n/lcPublic.c
index fac7d1d4..80459d6e 100644
--- a/src/xlibi18n/lcPublic.c
+++ b/src/xlibi18n/lcPublic.c
@@ -50,10 +50,10 @@ static XLCdPublicMethodsRec publicMethods = {
_XrmDefaultInitParseInfo,
_XmbTextPropertyToTextList,
_XwcTextPropertyToTextList,
- _XFree86utf8TextPropertyToTextList,
+ _Xutf8TextPropertyToTextList,
_XmbTextListToTextProperty,
_XwcTextListToTextProperty,
- _XFree86utf8TextListToTextProperty,
+ _Xutf8TextListToTextProperty,
_XwcFreeStringList,
default_string,
NULL,
diff --git a/src/xlibi18n/lcStd.c b/src/xlibi18n/lcStd.c
index b57579d3..b8e5ae4c 100644
--- a/src/xlibi18n/lcStd.c
+++ b/src/xlibi18n/lcStd.c
@@ -319,7 +319,7 @@ _Xwcsncmp(
int
-_XFree86lcmbstoutf8(
+_Xlcmbstoutf8(
XLCd lcd,
char *ustr,
const char *str,
@@ -335,7 +335,7 @@ _XFree86lcmbstoutf8(
return -1;
}
- conv = _XlcOpenConverter(lcd, XlcNMultiByte, lcd, XFree86lcNUtf8String);
+ conv = _XlcOpenConverter(lcd, XlcNMultiByte, lcd, XlcNUtf8String);
if (conv == NULL)
return -1;
@@ -358,10 +358,10 @@ _XFree86lcmbstoutf8(
}
int
-_XFree86mbstoutf8(
+_Xmbstoutf8(
char *ustr,
const char *str,
int len)
{
- return _XFree86lcmbstoutf8((XLCd) NULL, ustr, str, len);
+ return _Xlcmbstoutf8((XLCd) NULL, ustr, str, len);
}
diff --git a/src/xlibi18n/lcTxtPr.c b/src/xlibi18n/lcTxtPr.c
index 50c102ae..25e03c8a 100644
--- a/src/xlibi18n/lcTxtPr.c
+++ b/src/xlibi18n/lcTxtPr.c
@@ -97,9 +97,9 @@ _XTextListToTextProperty(
encoding = XA_STRING;
to_type = XlcNString;
break;
- case XFree86Utf8StringStyle:
+ case XUTF8StringStyle:
encoding = XInternAtom(dpy, "UTF8_STRING", False);
- to_type = XFree86lcNUtf8String;
+ to_type = XlcNUtf8String;
break;
case XCompoundTextStyle:
encoding = XInternAtom(dpy, "COMPOUND_TEXT", False);
@@ -240,7 +240,7 @@ _XwcTextListToTextProperty(
}
int
-_XFree86utf8TextListToTextProperty(
+_Xutf8TextListToTextProperty(
XLCd lcd,
Display *dpy,
char **list,
@@ -248,6 +248,6 @@ _XFree86utf8TextListToTextProperty(
XICCEncodingStyle style,
XTextProperty *text_prop)
{
- return _XTextListToTextProperty(lcd, dpy, XFree86lcNUtf8String,
- (XPointer) list, count, style, text_prop);
+ return _XTextListToTextProperty(lcd, dpy, XlcNUtf8String, (XPointer) list,
+ count, style, text_prop);
}
diff --git a/src/xlibi18n/lcWrap.c b/src/xlibi18n/lcWrap.c
index 3af14080..ef203420 100644
--- a/src/xlibi18n/lcWrap.c
+++ b/src/xlibi18n/lcWrap.c
@@ -406,7 +406,7 @@ XwcTextPropertyToTextList(
}
int
-XFree86utf8TextPropertyToTextList(
+Xutf8TextPropertyToTextList(
Display *dpy,
const XTextProperty *text_prop,
char ***list_ret,
@@ -420,18 +420,6 @@ XFree86utf8TextPropertyToTextList(
return (*lcd->methods->utf8_text_prop_to_list)(lcd, dpy, text_prop,
list_ret, count_ret);
}
-#ifndef NOXFREE86COMPAT
-#undef Xutf8TextPropertyToTextList
-int
-Xutf8TextPropertyToTextList(
- Display *dpy,
- const XTextProperty *text_prop,
- char ***list_ret,
- int *count_ret)
-{
- return XFree86utf8TextPropertyToTextList(dpy, text_prop, list_ret, count_ret);
-}
-#endif
int
XmbTextListToTextProperty(
@@ -468,7 +456,7 @@ XwcTextListToTextProperty(
}
int
-XFree86utf8TextListToTextProperty(
+Xutf8TextListToTextProperty(
Display *dpy,
char **list,
int count,
@@ -483,19 +471,6 @@ XFree86utf8TextListToTextProperty(
return (*lcd->methods->utf8_text_list_to_prop)(lcd, dpy, list, count,
style, text_prop);
}
-#ifndef NOXFREE86COMPAT
-#undef Xutf8TextListToTextProperty
-int
-Xutf8TextListToTextProperty(
- Display *dpy,
- char **list,
- int count,
- XICCEncodingStyle style,
- XTextProperty *text_prop)
-{
- return XFree86utf8TextListToTextProperty(dpy, list, count, style, text_prop);
-}
-#endif
void
XwcFreeStringList(
diff --git a/src/xlibi18n/utf8WMProps.c b/src/xlibi18n/utf8WMProps.c
index 4923ae98..11a224d0 100644
--- a/src/xlibi18n/utf8WMProps.c
+++ b/src/xlibi18n/utf8WMProps.c
@@ -56,7 +56,7 @@ from The Open Group.
#include <X11/Xlocale.h>
void
-XFree86utf8SetWMProperties (
+Xutf8SetWMProperties (
Display *dpy,
Window w,
_Xconst char *windowName,
@@ -72,11 +72,11 @@ XFree86utf8SetWMProperties (
XTextProperty *iprop = NULL;
if (windowName &&
- XFree86utf8TextListToTextProperty(dpy, (char**)&windowName, 1,
+ Xutf8TextListToTextProperty(dpy, (char**)&windowName, 1,
XStdICCTextStyle, &wname) >= Success)
wprop = &wname;
if (iconName &&
- XFree86utf8TextListToTextProperty(dpy, (char**)&iconName, 1,
+ Xutf8TextListToTextProperty(dpy, (char**)&iconName, 1,
XStdICCTextStyle, &iname) >= Success)
iprop = &iname;
XSetWMProperties(dpy, w, wprop, iprop, argv, argc,
@@ -88,21 +88,3 @@ XFree86utf8SetWMProperties (
/* Note: The WM_LOCALE_NAME property is set by XSetWMProperties. */
}
-#ifndef NOXFREE86COMPAT
-#undef Xutf8SetWMProperties
-void
-Xutf8SetWMProperties (
- Display *dpy,
- Window w,
- _Xconst char *windowName,
- _Xconst char *iconName,
- char **argv,
- int argc,
- XSizeHints *sizeHints,
- XWMHints *wmHints,
- XClassHint *classHints)
-{
- XFree86utf8SetWMProperties (dpy, w, windowName, iconName, argv, argc,
- sizeHints, wmHints, classHints);
-}
-#endif
diff --git a/src/xlibi18n/utf8Wrap.c b/src/xlibi18n/utf8Wrap.c
index 9ecc7225..70cc8a6e 100644
--- a/src/xlibi18n/utf8Wrap.c
+++ b/src/xlibi18n/utf8Wrap.c
@@ -78,7 +78,7 @@ from The Open Group.
#include "Xlcint.h"
void
-XFree86utf8DrawText(
+Xutf8DrawText(
Display *dpy,
Drawable d,
GC gc,
@@ -109,24 +109,9 @@ XFree86utf8DrawText(
x += esc;
}
}
-#ifndef NOXFREE86COMPAT
-#undef Xutf8DrawText
-void
-Xutf8DrawText(
- Display *dpy,
- Drawable d,
- GC gc,
- int x,
- int y,
- XmbTextItem *text_items,
- int nitems)
-{
- XFree86utf8DrawText(dpy, d, gc, x, y, text_items, nitems);
-}
-#endif
void
-XFree86utf8DrawString(
+Xutf8DrawString(
Display *dpy,
Drawable d,
XFontSet font_set,
@@ -139,25 +124,10 @@ XFree86utf8DrawString(
(void)(*font_set->methods->utf8_draw_string) (dpy, d, font_set, gc, x, y,
(char *)text, text_len);
}
-#ifndef NOXFREE86COMPAT
-#undef Xutf8DrawString
-void
-Xutf8DrawString(
- Display *dpy,
- Drawable d,
- XFontSet font_set,
- GC gc,
- int x,
- int y,
- _Xconst char *text,
- int text_len)
-{
- XFree86utf8DrawString(dpy, d, font_set, gc, x, y, text, text_len);
-}
-#endif
+
void
-XFree86utf8DrawImageString(
+Xutf8DrawImageString(
Display *dpy,
Drawable d,
XFontSet font_set,
@@ -170,25 +140,9 @@ XFree86utf8DrawImageString(
(*font_set->methods->utf8_draw_image_string) (dpy, d, font_set, gc, x, y,
(char *)text, text_len);
}
-#ifndef NOXFREE86COMPAT
-#undef Xutf8DrawImageString
-void
-Xutf8DrawImageString(
- Display *dpy,
- Drawable d,
- XFontSet font_set,
- GC gc,
- int x,
- int y,
- _Xconst char *text,
- int text_len)
-{
- XFree86utf8DrawImageString(dpy, d, font_set, gc, x, y, text, text_len);
-}
-#endif
int
-XFree86utf8TextEscapement(
+Xutf8TextEscapement(
XFontSet font_set,
_Xconst char *text,
int text_len)
@@ -196,20 +150,9 @@ XFree86utf8TextEscapement(
return (*font_set->methods->utf8_escapement) (font_set,
(char *)text, text_len);
}
-#ifndef NOXFREE86COMPAT
-#undef Xutf8TextEscapement
-int
-Xutf8TextEscapement(
- XFontSet font_set,
- _Xconst char *text,
- int text_len)
-{
- return XFree86utf8TextEscapement(font_set, text, text_len);
-}
-#endif
int
-XFree86utf8TextExtents(
+Xutf8TextExtents(
XFontSet font_set,
_Xconst char *text,
int text_len,
@@ -221,23 +164,9 @@ XFree86utf8TextExtents(
overall_ink_extents,
overall_logical_extents);
}
-#ifndef NOXFREE86COMPAT
-#undef Xutf8TextExtents
-int
-Xutf8TextExtents(
- XFontSet font_set,
- _Xconst char *text,
- int text_len,
- XRectangle *overall_ink_extents,
- XRectangle *overall_logical_extents)
-{
- return XFree86utf8TextExtents(font_set, text, text_len,
- overall_ink_extents, overall_logical_extents);
-}
-#endif
Status
-XFree86utf8TextPerCharExtents(
+Xutf8TextPerCharExtents(
XFontSet font_set,
_Xconst char *text,
int text_len,
@@ -253,22 +182,3 @@ XFree86utf8TextPerCharExtents(
ink_extents_buffer, logical_extents_buffer,
buffer_size, num_chars, max_ink_extents, max_logical_extents);
}
-#ifndef NOXFREE86COMPAT
-#undef Xutf8TextPerCharExtents
-Status
-Xutf8TextPerCharExtents(
- XFontSet font_set,
- _Xconst char *text,
- int text_len,
- XRectangle *ink_extents_buffer,
- XRectangle *logical_extents_buffer,
- int buffer_size,
- int *num_chars,
- XRectangle *max_ink_extents,
- XRectangle *max_logical_extents)
-{
- return XFree86utf8TextPerCharExtents(font_set, text, text_len,
- ink_extents_buffer, logical_extents_buffer, buffer_size,
- num_chars, max_ink_extents, max_logical_extents);
-}
-#endif
diff --git a/src/xlibi18n/lcUTF8.c b/src/xlibi18n/lcUTF8.c
index 10ecf12b..972a192d 100644
--- a/src/xlibi18n/lcUTF8.c
+++ b/src/xlibi18n/lcUTF8.c
@@ -371,7 +371,8 @@ init_all_charsets (void)
init_all_charsets(); \
} while (0)
-/* from XlcNCharSet to XFree86lcNUtf8String */
+/* from XlcNCharSet to XlcNUtf8String */
+
static int
cstoutf8(
XlcConv conv,
@@ -463,7 +464,7 @@ open_cstoutf8(
return create_conv(from_lcd, &methods_cstoutf8);
}
/* from XFree86lcNUtf8String to XlcNCharSet */
static XlcConv
create_tocs_conv(
@@ -677,7 +678,7 @@ open_utf8tocs(
return create_tocs_conv(from_lcd, &methods_utf8tocs);
}
/* from XFree86lcNUtf8String to XlcNChar */
static int
utf8tocs1(
@@ -781,7 +782,7 @@ open_utf8tocs1(
return create_tocs_conv(from_lcd, &methods_utf8tocs1);
}
/* from XFree86lcNUtf8String to XlcNString */
static int
utf8tostr(
@@ -857,7 +858,7 @@ open_utf8tostr(
return create_conv(from_lcd, &methods_utf8tostr);
}
/* from XlcNString to XFree86lcNUtf8String */
static int
strtoutf8(
@@ -917,7 +918,7 @@ open_strtoutf8(
/* Support for the input methods. */
XPointer
-_XFree86utf8GetConvByName(
+_Utf8GetConvByName(
const char *name)
{
XrmQuark xrm_name;
@@ -1055,7 +1056,7 @@ open_ucstocs1(
return create_ucstocs_conv(from_lcd, &methods_ucstocs1);
}
/* from XlcNUcsChar to XFree86lcNUtf8String, needed for input methods */
static int
ucstoutf8(
@@ -1118,16 +1119,16 @@ open_ucstoutf8(
/* Registers UTF-8 converters for a non-UTF-8 locale. */
void
-_XFree86lcAddUtf8Converters(
+_XlcAddUtf8Converters(
XLCd lcd)
{
- _XlcSetConverter(lcd, XlcNCharSet, lcd, XFree86lcNUtf8String, open_cstoutf8);
- _XlcSetConverter(lcd, XFree86lcNUtf8String, lcd, XlcNCharSet, open_utf8tocs);
- _XlcSetConverter(lcd, XFree86lcNUtf8String, lcd, XlcNChar, open_utf8tocs1);
- _XlcSetConverter(lcd, XlcNString, lcd, XFree86lcNUtf8String, open_strtoutf8);
- _XlcSetConverter(lcd, XFree86lcNUtf8String, lcd, XlcNString, open_utf8tostr);
+ _XlcSetConverter(lcd, XlcNCharSet, lcd, XlcNUtf8String, open_cstoutf8);
+ _XlcSetConverter(lcd, XlcNUtf8String, lcd, XlcNCharSet, open_utf8tocs);
+ _XlcSetConverter(lcd, XlcNUtf8String, lcd, XlcNChar, open_utf8tocs1);
+ _XlcSetConverter(lcd, XlcNString, lcd, XlcNUtf8String, open_strtoutf8);
+ _XlcSetConverter(lcd, XlcNUtf8String, lcd, XlcNString, open_utf8tostr);
_XlcSetConverter(lcd, XlcNUcsChar, lcd, XlcNChar, open_ucstocs1);
- _XlcSetConverter(lcd, XlcNUcsChar, lcd, XFree86lcNUtf8String, open_ucstoutf8);
+ _XlcSetConverter(lcd, XlcNUcsChar, lcd, XlcNUtf8String, open_ucstoutf8);
}
/***************************************************************************/
@@ -1801,7 +1802,7 @@ open_utf8tofcs(
/* Registers UTF-8 converters for a UTF-8 locale. */
void
-_XFree86lcAddUtf8LocaleConverters(
+_XlcAddUtf8LocaleConverters(
XLCd lcd)
{
/* Register elementary converters. */
@@ -1826,8 +1827,8 @@ _XFree86lcAddUtf8LocaleConverters(
_XlcSetConverter(lcd, XlcNString, lcd, XlcNMultiByte, open_strtoutf8);
_XlcSetConverter(lcd, XlcNMultiByte, lcd, XlcNString, open_utf8tostr);
- _XlcSetConverter(lcd, XFree86lcNUtf8String, lcd, XlcNMultiByte, open_identity);
- _XlcSetConverter(lcd, XlcNMultiByte, lcd, XFree86lcNUtf8String, open_identity);
+ _XlcSetConverter(lcd, XlcNUtf8String, lcd, XlcNMultiByte, open_identity);
+ _XlcSetConverter(lcd, XlcNMultiByte, lcd, XlcNUtf8String, open_identity);
/* Register converters for XlcNFontCharSet */
_XlcSetConverter(lcd, XlcNMultiByte, lcd, XlcNFontCharSet, open_utf8tofcs);
@@ -463,7 +464,7 @@ open_cstoutf8(
return create_conv(from_lcd, &methods_cstoutf8);
}
-/* from XFree86lcNUtf8String to XlcNCharSet */
+/* from XlcNUtf8String to XlcNCharSet */
static XlcConv
create_tocs_conv(
@@ -677,7 +678,7 @@ open_utf8tocs(
return create_tocs_conv(from_lcd, &methods_utf8tocs);
}
-/* from XFree86lcNUtf8String to XlcNChar */
+/* from XlcNUtf8String to XlcNChar */
static int
utf8tocs1(
@@ -781,7 +782,7 @@ open_utf8tocs1(
return create_tocs_conv(from_lcd, &methods_utf8tocs1);
}
-/* from XFree86lcNUtf8String to XlcNString */
+/* from XlcNUtf8String to XlcNString */
static int
utf8tostr(
@@ -857,7 +858,7 @@ open_utf8tostr(
return create_conv(from_lcd, &methods_utf8tostr);
}
-/* from XlcNString to XFree86lcNUtf8String */
+/* from XlcNString to XlcNUtf8String */
static int
strtoutf8(
@@ -1055,7 +1056,7 @@ open_ucstocs1(
return create_ucstocs_conv(from_lcd, &methods_ucstocs1);
}
-/* from XlcNUcsChar to XFree86lcNUtf8String, needed for input methods */
+/* from XlcNUcsChar to XlcNUtf8String, needed for input methods */
static int
ucstoutf8(